@@ -12,11 +12,11 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from http import client as http_client
+
 from oslo_config import cfg
 from oslo_log import log
 from pecan import rest
-from six.moves import http_client
-from wsme import types as wtypes
 
 from ironic import api
 from ironic.api.controllers import base
@@ -62,7 +62,7 @@ class LookupResult(base.APIBase):
     node = node_ctl.Node
     """The short node representation."""
 
-    config = {wtypes.text: types.jsontype}
+    config = {str: types.jsontype}
     """The configuration to pass to the ramdisk."""
 
     @classmethod
@@ -155,8 +155,8 @@ class LookupController(rest.RestController):
 class HeartbeatController(rest.RestController):
     """Controller handling heartbeats from deploy ramdisk."""
 
-    @expose.expose(None, types.uuid_or_name, wtypes.text,
-                   wtypes.text, status_code=http_client.ACCEPTED)
+    @expose.expose(None, types.uuid_or_name, str,
+                   str, status_code=http_client.ACCEPTED)
     def post(self, node_ident, callback_url, agent_version=None):
         """Process a heartbeat from the deploy ramdisk.
 
