@@ -21,10 +21,10 @@ import json
 from oslo_log import log
 from oslo_utils import strutils
 from oslo_utils import uuidutils
-import six
 import wsme
 from wsme import types as wtypes
 
+from ironic.api.controllers import base
 from ironic.api.controllers.v1 import utils as v1_utils
 from ironic.common import exception
 from ironic.common.i18n import _
@@ -37,7 +37,7 @@ LOG = log.getLogger(__name__)
 class MacAddressType(wtypes.UserType):
     """A simple MAC address type."""
 
-    basetype = wtypes.text
+    basetype = str
     name = 'macaddress'
 
     @staticmethod
@@ -54,7 +54,7 @@ class MacAddressType(wtypes.UserType):
 class UuidOrNameType(wtypes.UserType):
     """A simple UUID or logical name type."""
 
-    basetype = wtypes.text
+    basetype = str
     name = 'uuid_or_name'
 
     @staticmethod
@@ -74,7 +74,7 @@ class UuidOrNameType(wtypes.UserType):
 class NameType(wtypes.UserType):
     """A simple logical name type."""
 
-    basetype = wtypes.text
+    basetype = str
     name = 'name'
 
     @staticmethod
@@ -93,7 +93,7 @@ class NameType(wtypes.UserType):
 class UuidType(wtypes.UserType):
     """A simple UUID type."""
 
-    basetype = wtypes.text
+    basetype = str
     name = 'uuid'
 
     @staticmethod
@@ -112,7 +112,7 @@ class UuidType(wtypes.UserType):
 class BooleanType(wtypes.UserType):
     """A simple boolean type."""
 
-    basetype = wtypes.text
+    basetype = str
     name = 'boolean'
 
     @staticmethod
@@ -121,7 +121,7 @@ class BooleanType(wtypes.UserType):
             return strutils.bool_from_string(value, strict=True)
         except ValueError as e:
             # raise Invalid to return 400 (BadRequest) in the API
-            raise exception.Invalid(six.text_type(e))
+            raise exception.Invalid(str(e))
 
     @staticmethod
     def frombasetype(value):
@@ -133,12 +133,12 @@ class BooleanType(wtypes.UserType):
 class JsonType(wtypes.UserType):
     """A simple JSON type."""
 
-    basetype = wtypes.text
+    basetype = str
     name = 'json'
 
     def __str__(self):
         # These are the json serializable native types
-        return ' | '.join(map(str, (wtypes.text, six.integer_types, float,
+        return ' | '.join(map(str, (str, int, float,
                                     BooleanType, list, dict, None)))
 
     @staticmethod
@@ -158,7 +158,7 @@ class JsonType(wtypes.UserType):
 class ListType(wtypes.UserType):
     """A simple list type."""
 
-    basetype = wtypes.text
+    basetype = str
     name = 'list'
 
     @staticmethod
@@ -170,7 +170,7 @@ class ListType(wtypes.UserType):
                   same order
         """
         items = []
-        for v in six.text_type(value).split(','):
+        for v in str(value).split(','):
             v_norm = v.strip().lower()
             if v_norm and v_norm not in items:
                 items.append(v_norm)
@@ -193,7 +193,7 @@ listtype = ListType()
 jsontype = JsonType()
 
 
-class JsonPatchType(wtypes.Base):
+class JsonPatchType(base.Base):
     """A complex type that represents a single json-patch operation."""
 
     path = wtypes.wsattr(wtypes.StringType(pattern='^(/[\\w-]+)+$'),
@@ -247,16 +247,16 @@ class JsonPatchType(wtypes.Base):
         _path = '/' + patch.path.split('/')[1]
         if _path in patch.internal_attrs():
             msg = _("'%s' is an internal attribute and can not be updated")
-            raise wsme.exc.ClientSideError(msg % patch.path)
+            raise exception.ClientSideError(msg % patch.path)
 
         if patch.path in patch.non_removable_attrs() and patch.op == 'remove':
             msg = _("'%s' is a mandatory attribute and can not be removed")
-            raise wsme.exc.ClientSideError(msg % patch.path)
+            raise exception.ClientSideError(msg % patch.path)
 
         if patch.op != 'remove':
             if patch.value is wsme.Unset:
                 msg = _("'add' and 'replace' operations need a value")
-                raise wsme.exc.ClientSideError(msg)
+                raise exception.ClientSideError(msg)
 
         ret = {'path': patch.path, 'op': patch.op}
         if patch.value is not wsme.Unset:
@@ -304,7 +304,7 @@ class LocalLinkConnectionType(wtypes.UserType):
         :raises: Invalid if some of the keys in the dictionary being validated
             are unknown, invalid, or some required ones are missing.
         """
-        wtypes.DictType(wtypes.text, wtypes.text).validate(value)
+        wtypes.DictType(str, str).validate(value)
 
         keys = set(value)
 
@@ -365,7 +365,7 @@ class LocalLinkConnectionType(wtypes.UserType):
         :return: True if both fields 'port_id' and 'hostname' are present
             in 'value', False otherwise.
         """
-        wtypes.DictType(wtypes.text, wtypes.text).validate(value)
+        wtypes.DictType(str, str).validate(value)
         keys = set(value)
 
         if LocalLinkConnectionType.smart_nic_mandatory_fields <= keys:
@@ -378,7 +378,7 @@ locallinkconnectiontype = LocalLinkConnectionType()
 
 class VifType(JsonType):
 
-    basetype = wtypes.text
+    basetype = str
     name = 'viftype'
 
     mandatory_fields = {'id'}
@@ -423,10 +423,10 @@ class EventType(wtypes.UserType):
         validators = {
             'port_id': UuidType.validate,
             'mac_address': MacAddressType.validate,
-            'status': wtypes.text,
+            'status': str,
             'device_id': UuidType.validate,
             'binding:host_id': UuidType.validate,
-            'binding:vnic_type': wtypes.text
+            'binding:vnic_type': str
         }
 
         keys = set(value)
@@ -474,7 +474,7 @@ class EventType(wtypes.UserType):
         :raises: Invalid if event not in proper format
         """
 
-        wtypes.DictType(wtypes.text, wtypes.text).validate(value)
+        wtypes.DictType(str, str).validate(value)
         keys = set(value)
 
         # Check all mandatory fields are present
