@@ -13,6 +13,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from http import client as http_client
 import inspect
 import re
 
@@ -23,8 +24,6 @@ import os_traits
 from oslo_config import cfg
 from oslo_utils import uuidutils
 from pecan import rest
-import six
-from six.moves import http_client
 from webob import static
 import wsme
 
@@ -42,7 +41,8 @@ from ironic import objects
 CONF = cfg.CONF
 
 
-_JSONPATCH_EXCEPTIONS = (jsonpatch.JsonPatchException,
+_JSONPATCH_EXCEPTIONS = (jsonpatch.JsonPatchConflict,
+                         jsonpatch.JsonPatchException,
                          jsonpatch.JsonPointerException,
                          KeyError,
                          IndexError)
@@ -83,27 +83,27 @@ def validate_limit(limit):
         return CONF.api.max_limit
 
     if limit <= 0:
-        raise wsme.exc.ClientSideError(_("Limit must be positive"))
+        raise exception.ClientSideError(_("Limit must be positive"))
 
     return min(CONF.api.max_limit, limit)
 
 
 def validate_sort_dir(sort_dir):
     if sort_dir not in ['asc', 'desc']:
-        raise wsme.exc.ClientSideError(_("Invalid sort direction: %s. "
-                                         "Acceptable values are "
-                                         "'asc' or 'desc'") % sort_dir)
+        raise exception.ClientSideError(_("Invalid sort direction: %s. "
+                                          "Acceptable values are "
+                                          "'asc' or 'desc'") % sort_dir)
     return sort_dir
 
 
 def validate_trait(trait, error_prefix=_('Invalid trait')):
-    error = wsme.exc.ClientSideError(
+    error = exception.ClientSideError(
         _('%(error_prefix)s. A valid trait must be no longer than 255 '
           'characters. Standard traits are defined in the os_traits library. '
           'A custom trait must start with the prefix CUSTOM_ and use '
           'the following characters: A-Z, 0-9 and _') %
         {'error_prefix': error_prefix})
-    if not isinstance(trait, six.string_types):
+    if not isinstance(trait, str):
         raise error
 
     if len(trait) > 255 or len(trait) < 1:
@@ -126,7 +126,7 @@ def apply_jsonpatch(doc, patch):
     :param patch: The JSON patch to apply.
     :returns: The result of the patch operation.
     :raises: PatchError if the patch fails to apply.
-    :raises: wsme.exc.ClientSideError if the patch adds a new root attribute.
+    :raises: exception.ClientSideError if the patch adds a new root attribute.
     """
     # Prevent removal of root attributes.
     for p in patch:
@@ -134,7 +134,7 @@ def apply_jsonpatch(doc, patch):
             if p['path'].lstrip('/') not in doc:
                 msg = _('Adding a new attribute (%s) to the root of '
                         'the resource is not allowed')
-                raise wsme.exc.ClientSideError(msg % p['path'])
+                raise exception.ClientSideError(msg % p['path'])
 
     # Apply operations one at a time, to improve error reporting.
     for patch_op in patch:
@@ -404,7 +404,7 @@ def vendor_passthru(ident, method, topic, data=None, driver_passthru=False):
 
     """
     if not method:
-        raise wsme.exc.ClientSideError(_("Method not specified"))
+        raise exception.ClientSideError(_("Method not specified"))
 
     if data is None:
         data = {}
@@ -422,7 +422,7 @@ def vendor_passthru(ident, method, topic, data=None, driver_passthru=False):
 
     # Attach the return value to the response object
     if response.get('attach'):
-        if isinstance(return_value, six.text_type):
+        if isinstance(return_value, str):
             # If unicode, convert to bytes
             return_value = return_value.encode('utf-8')
         file_ = wsme.types.File(content=return_value)
@@ -488,6 +488,8 @@ VERSIONED_FIELDS = {
     'description': versions.MINOR_51_NODE_DESCRIPTION,
     'allocation_uuid': versions.MINOR_52_ALLOCATION,
     'events': versions.MINOR_54_EVENTS,
+    'retired': versions.MINOR_61_NODE_RETIRED,
+    'retired_reason': versions.MINOR_61_NODE_RETIRED,
 }
 
 for field in V31_FIELDS:
@@ -616,7 +618,8 @@ _CONFIG_DRIVE_SCHEMA = {
                 'network_data': {'type': 'object'},
                 'user_data': {
                     'type': ['object', 'array', 'string', 'null']
-                }
+                },
+                'vendor_data': {'type': 'object'},
             },
             'additionalProperties': False
         },
@@ -638,23 +641,32 @@ def check_allow_configdrive(target, configdrive=None):
     if target not in allowed_targets:
         msg = (_('Adding a config drive is only supported when setting '
                  'provision state to %s') % ', '.join(allowed_targets))
-        raise wsme.exc.ClientSideError(
+        raise exception.ClientSideError(
             msg, status_code=http_client.BAD_REQUEST)
 
     try:
         jsonschema.validate(configdrive, _CONFIG_DRIVE_SCHEMA)
     except json_schema_exc.ValidationError as e:
         msg = _('Invalid configdrive format: %s') % e
-        raise wsme.exc.ClientSideError(
+        raise exception.ClientSideError(
             msg, status_code=http_client.BAD_REQUEST)
 
-    if isinstance(configdrive, dict) and not allow_build_configdrive():
-        msg = _('Providing a JSON object for configdrive is only supported'
-                ' starting with API version %(base)s.%(opr)s') % {
-                    'base': versions.BASE_VERSION,
-                    'opr': versions.MINOR_56_BUILD_CONFIGDRIVE}
-        raise wsme.exc.ClientSideError(
-            msg, status_code=http_client.BAD_REQUEST)
+    if isinstance(configdrive, dict):
+        if not allow_build_configdrive():
+            msg = _('Providing a JSON object for configdrive is only supported'
+                    ' starting with API version %(base)s.%(opr)s') % {
+                        'base': versions.BASE_VERSION,
+                        'opr': versions.MINOR_56_BUILD_CONFIGDRIVE}
+            raise exception.ClientSideError(
+                msg, status_code=http_client.BAD_REQUEST)
+        if ('vendor_data' in configdrive and
+            not allow_configdrive_vendor_data()):
+            msg = _('Providing vendor_data in configdrive is only supported'
+                    ' starting with API version %(base)s.%(opr)s') % {
+                        'base': versions.BASE_VERSION,
+                        'opr': versions.MINOR_59_CONFIGDRIVE_VENDOR_DATA}
+            raise exception.ClientSideError(
+                msg, status_code=http_client.BAD_REQUEST)
 
 
 def check_allow_filter_by_fault(fault):
@@ -673,7 +685,7 @@ def check_allow_filter_by_fault(fault):
         msg = (_('Unrecognized fault "%(fault)s" is specified, allowed faults '
                  'are %(valid_faults)s') %
                {'fault': fault, 'valid_faults': faults.VALID_FAULTS})
-        raise wsme.exc.ClientSideError(
+        raise exception.ClientSideError(
             msg, status_code=http_client.BAD_REQUEST)
 
 
@@ -1155,6 +1167,116 @@ def check_policy(policy_name):
     policy.authorize(policy_name, cdict, cdict)
 
 
+def check_node_policy(policy_name, node_owner):
+    """Check if the specified policy authorizes this request on a node.
+
+    :param: policy_name: Name of the policy to check.
+    :param: node_owner: the node owner
+
+    :raises: HTTPForbidden if the policy forbids access.
+    """
+    cdict = api.request.context.to_policy_values()
+
+    target_dict = dict(cdict)
+    target_dict['node.owner'] = node_owner
+    policy.authorize(policy_name, target_dict, cdict)
+
+
+def check_node_policy_and_retrieve(policy_name, node_ident,
+                                   with_suffix=False):
+    """Check if the specified policy authorizes this request on a node.
+
+    :param: policy_name: Name of the policy to check.
+    :param: node_ident: the UUID or logical name of a node.
+    :param: with_suffix: whether the RPC node should include the suffix
+
+    :raises: HTTPForbidden if the policy forbids access.
+    :raises: NodeNotFound if the node is not found.
+    :return: RPC node identified by node_ident
+    """
+    try:
+        if with_suffix:
+            rpc_node = get_rpc_node_with_suffix(node_ident)
+        else:
+            rpc_node = get_rpc_node(node_ident)
+    except exception.NodeNotFound:
+        # don't expose non-existence of node unless requester
+        # has generic access to policy
+        cdict = api.request.context.to_policy_values()
+        policy.authorize(policy_name, cdict, cdict)
+        raise
+
+    check_node_policy(policy_name, rpc_node['owner'])
+    return rpc_node
+
+
+def check_node_list_policy(owner=None):
+    """Check if the specified policy authorizes this request on a node.
+
+    :param: owner: owner filter for list query, if any
+
+    :raises: HTTPForbidden if the policy forbids access.
+    :raises: NodeNotFound if the node is not found.
+    :return: owner that should be used for list query, if needed
+    """
+    cdict = api.request.context.to_policy_values()
+    try:
+        policy.authorize('baremetal:node:list_all', cdict, cdict)
+    except exception.HTTPForbidden:
+        project_owner = cdict.get('project_id')
+        if (not project_owner or (owner and owner != project_owner)):
+            raise
+        policy.authorize('baremetal:node:list', cdict, cdict)
+        return project_owner
+    return owner
+
+
+def check_port_policy_and_retrieve(policy_name, port_uuid):
+    """Check if the specified policy authorizes this request on a port.
+
+    :param: policy_name: Name of the policy to check.
+    :param: port_uuid: the UUID of a port.
+
+    :raises: HTTPForbidden if the policy forbids access.
+    :raises: NodeNotFound if the node is not found.
+    :return: RPC port identified by port_uuid and associated node
+    """
+    context = api.request.context
+    cdict = context.to_policy_values()
+
+    try:
+        rpc_port = objects.Port.get_by_uuid(context, port_uuid)
+    except exception.PortNotFound:
+        # don't expose non-existence of port unless requester
+        # has generic access to policy
+        policy.authorize(policy_name, cdict, cdict)
+        raise
+
+    rpc_node = objects.Node.get_by_id(context, rpc_port.node_id)
+    target_dict = dict(cdict)
+    target_dict['node.owner'] = rpc_node['owner']
+    policy.authorize(policy_name, target_dict, cdict)
+
+    return rpc_port, rpc_node
+
+
+def check_port_list_policy():
+    """Check if the specified policy authorizes this request on a port.
+
+    :raises: HTTPForbidden if the policy forbids access.
+    :return: owner that should be used for list query, if needed
+    """
+    cdict = api.request.context.to_policy_values()
+    try:
+        policy.authorize('baremetal:port:list_all', cdict, cdict)
+    except exception.HTTPForbidden:
+        owner = cdict.get('project_id')
+        if not owner:
+            raise
+        policy.authorize('baremetal:port:list', cdict, cdict)
+        return owner
+
+
 def allow_build_configdrive():
     """Check if building configdrive is allowed.
 
@@ -1163,6 +1285,15 @@ def allow_build_configdrive():
     return api.request.version.minor >= versions.MINOR_56_BUILD_CONFIGDRIVE
 
 
+def allow_configdrive_vendor_data():
+    """Check if configdrive can contain a vendor_data key.
+
+    Version 1.59 of the API added support for configdrive vendor_data.
+    """
+    return (api.request.version.minor >=
+            versions.MINOR_59_CONFIGDRIVE_VENDOR_DATA)
+
+
 def allow_allocation_update():
     """Check if updating an existing allocation is allowed or not.
 
@@ -1177,3 +1308,11 @@ def allow_allocation_backfill():
     Version 1.58 of the API added support for backfilling allocations.
     """
     return api.request.version.minor >= versions.MINOR_58_ALLOCATION_BACKFILL
+
+
+def allow_allocation_owner():
+    """Check if allocation owner field is allowed.
+
+    Version 1.60 of the API added the owner field to the allocation object.
+    """
+    return api.request.version.minor >= versions.MINOR_60_ALLOCATION_OWNER
