@@ -16,9 +16,11 @@
 
 """Ironic specific exceptions list."""
 
+from http import client as http_client
+
 from ironic_lib.exception import IronicException
 from oslo_log import log as logging
-from six.moves import http_client
+import wsme
 
 from ironic.common.i18n import _
 
@@ -704,3 +706,12 @@ class IBMCError(DriverOperationError):
 
 class IBMCConnectionError(IBMCError):
     _msg_fmt = _("IBMC connection failed for node %(node)s: %(error)s")
+
+
+class ClientSideError(wsme.exc.ClientSideError):
+    pass
+
+
+class NodeIsRetired(Invalid):
+    _msg_fmt = _("The %(op)s operation can't be performed on node "
+                 "%(node)s because it is retired.")
