@@ -63,6 +63,9 @@ default_policies = [
     policy.RuleDefault('is_admin',
                        'rule:admin_api or (rule:is_member and role:baremetal_admin)',  # noqa
                        description='Full read/write API access'),
+    policy.RuleDefault('is_node_owner',
+                       'project_id:%(node.owner)s',
+                       description='Owner of node'),
 ]
 
 # NOTE(deva): to follow policy-in-code spec, we define defaults for
@@ -79,15 +82,30 @@ node_policies = [
     policy.DocumentedRuleDefault(
         'baremetal:node:get',
         'rule:is_admin or rule:is_observer',
-        'Retrieve Node records',
+        'Retrieve a single Node record',
+        [{'path': '/nodes/{node_ident}', 'method': 'GET'}]),
+    policy.DocumentedRuleDefault(
+        'baremetal:node:list',
+        'rule:baremetal:node:get',
+        'Retrieve multiple Node records, filtered by owner',
         [{'path': '/nodes', 'method': 'GET'},
-         {'path': '/nodes/detail', 'method': 'GET'},
-         {'path': '/nodes/{node_ident}', 'method': 'GET'}]),
+         {'path': '/nodes/detail', 'method': 'GET'}]),
+    policy.DocumentedRuleDefault(
+        'baremetal:node:list_all',
+        'rule:baremetal:node:get',
+        'Retrieve multiple Node records',
+        [{'path': '/nodes', 'method': 'GET'},
+         {'path': '/nodes/detail', 'method': 'GET'}]),
     policy.DocumentedRuleDefault(
         'baremetal:node:update',
         'rule:is_admin',
         'Update Node records',
         [{'path': '/nodes/{node_ident}', 'method': 'PATCH'}]),
+    policy.DocumentedRuleDefault(
+        'baremetal:node:update_owner_provisioned',
+        'rule:is_admin',
+        'Update Node owner even when Node is provisioned',
+        [{'path': '/nodes/{node_ident}', 'method': 'PATCH'}]),
     policy.DocumentedRuleDefault(
         'baremetal:node:delete',
         'rule:is_admin',
@@ -213,14 +231,24 @@ port_policies = [
         'baremetal:port:get',
         'rule:is_admin or rule:is_observer',
         'Retrieve Port records',
-        [{'path': '/ports', 'method': 'GET'},
-         {'path': '/ports/detail', 'method': 'GET'},
-         {'path': '/ports/{port_id}', 'method': 'GET'},
+        [{'path': '/ports/{port_id}', 'method': 'GET'},
          {'path': '/nodes/{node_ident}/ports', 'method': 'GET'},
          {'path': '/nodes/{node_ident}/ports/detail', 'method': 'GET'},
          {'path': '/portgroups/{portgroup_ident}/ports', 'method': 'GET'},
          {'path': '/portgroups/{portgroup_ident}/ports/detail',
           'method': 'GET'}]),
+    policy.DocumentedRuleDefault(
+        'baremetal:port:list',
+        'rule:baremetal:port:get',
+        'Retrieve multiple Port records, filtered by owner',
+        [{'path': '/ports', 'method': 'GET'},
+         {'path': '/ports/detail', 'method': 'GET'}]),
+    policy.DocumentedRuleDefault(
+        'baremetal:port:list_all',
+        'rule:baremetal:port:get',
+        'Retrieve multiple Port records',
+        [{'path': '/ports', 'method': 'GET'},
+         {'path': '/ports/detail', 'method': 'GET'}]),
     policy.DocumentedRuleDefault(
         'baremetal:port:create',
         'rule:is_admin',
@@ -417,6 +445,11 @@ allocation_policies = [
         'rule:is_admin',
         'Create Allocation records',
         [{'path': '/allocations', 'method': 'POST'}]),
+    policy.DocumentedRuleDefault(
+        'baremetal:allocation:create_restricted',
+        'rule:baremetal:allocation:create',
+        'Create Allocation records that are restricted to an owner',
+        [{'path': '/allocations', 'method': 'POST'}]),
     policy.DocumentedRuleDefault(
         'baremetal:allocation:delete',
         'rule:is_admin',
