@@ -61,10 +61,7 @@ KERNEL_RAMDISK_LABELS = {'deploy': DEPLOY_KERNEL_RAMDISK_LABELS,
 
 def get_root_dir():
     """Returns the directory where the config files and images will live."""
-    if CONF.pxe.ipxe_enabled:
-        return CONF.deploy.http_root
-    else:
-        return CONF.pxe.tftp_root
+    return CONF.pxe.tftp_root
 
 
 def get_ipxe_root_dir():
@@ -347,6 +344,8 @@ def clean_up_pxe_config(task, ipxe_enabled=False):
     if is_uefi_boot_mode and not ipxe_enabled:
         api = dhcp_factory.DHCPFactory().provider
         ip_addresses = api.get_ip_addresses(task)
+        if not ip_addresses:
+            return
 
         for port_ip_address in ip_addresses:
             try:
@@ -720,12 +719,15 @@ def build_instance_pxe_options(task, pxe_info, ipxe_enabled=False):
     return pxe_opts
 
 
-def build_extra_pxe_options():
+def build_extra_pxe_options(ramdisk_params=None):
     # Enable debug in IPA according to CONF.debug if it was not
     # specified yet
     pxe_append_params = CONF.pxe.pxe_append_params
     if CONF.debug and 'ipa-debug' not in pxe_append_params:
         pxe_append_params += ' ipa-debug=1'
+    if ramdisk_params:
+        pxe_append_params += ' ' + ' '.join('%s=%s' % tpl
+                                            for tpl in ramdisk_params.items())
 
     return {'pxe_append_params': pxe_append_params,
             'tftp_server': CONF.pxe.tftp_server,
@@ -733,7 +735,7 @@ def build_extra_pxe_options():
 
 
 def build_pxe_config_options(task, pxe_info, service=False,
-                             ipxe_enabled=False):
+                             ipxe_enabled=False, ramdisk_params=None):
     """Build the PXE config options for a node
 
     This method builds the PXE boot options for a node,
@@ -749,6 +751,8 @@ def build_pxe_config_options(task, pxe_info, service=False,
         to PXE options.
     :param ipxe_enabled: Default false boolean to indicate if ipxe
                          is in use by the caller.
+    :param ramdisk_params: the parameters to be passed to the ramdisk.
+                           as kernel command-line arguments.
     :returns: A dictionary of pxe options to be used in the pxe bootfile
         template.
     """
@@ -771,7 +775,7 @@ def build_pxe_config_options(task, pxe_info, service=False,
     pxe_options.update(build_instance_pxe_options(task, pxe_info,
                                                   ipxe_enabled=ipxe_enabled))
 
-    pxe_options.update(build_extra_pxe_options())
+    pxe_options.update(build_extra_pxe_options(ramdisk_params))
 
     return pxe_options
 
