@@ -12,6 +12,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+import contextlib
 import datetime
 import time
 
@@ -22,7 +23,6 @@ from oslo_serialization import jsonutils
 from oslo_service import loopingcall
 from oslo_utils import excutils
 from oslo_utils import timeutils
-import six
 
 from ironic.common import boot_devices
 from ironic.common import exception
@@ -730,7 +730,7 @@ def validate_instance_info_traits(node):
     instance_traits = node.instance_info['traits']
     if not isinstance(instance_traits, list):
         invalid()
-    if not all(isinstance(t, six.string_types) for t in instance_traits):
+    if not all(isinstance(t, str) for t in instance_traits):
         invalid()
 
     node_traits = node.traits.get_trait_names()
@@ -831,6 +831,20 @@ def restore_power_state_if_needed(task, power_state_to_restore):
         node_power_action(task, power_state_to_restore)
 
 
+@contextlib.contextmanager
+def power_state_for_network_configuration(task):
+    """Handle the power state for a node reconfiguration.
+
+    Powers the node on if and only if it has a Smart NIC port. Yields for
+    the actual reconfiguration, then restores the power state.
+
+    :param task: A TaskManager object.
+    """
+    previous = power_on_node_if_needed(task)
+    yield task
+    restore_power_state_if_needed(task, previous)
+
+
 def build_configdrive(node, configdrive):
     """Build a configdrive from provided meta_data, network_data and user_data.
 
@@ -839,7 +853,7 @@ def build_configdrive(node, configdrive):
 
     :param node: an Ironic node object.
     :param configdrive: A configdrive as a dict with keys ``meta_data``,
-        ``network_data`` and ``user_data`` (all optional).
+        ``network_data``, ``user_data`` and ``vendor_data`` (all optional).
     :returns: A gzipped and base64 encoded configdrive as a string.
     """
     meta_data = configdrive.setdefault('meta_data', {})
@@ -855,7 +869,8 @@ def build_configdrive(node, configdrive):
 
     LOG.debug('Building a configdrive for node %s', node.uuid)
     return os_configdrive.build(meta_data, user_data=user_data,
-                                network_data=configdrive.get('network_data'))
+                                network_data=configdrive.get('network_data'),
+                                vendor_data=configdrive.get('vendor_data'))
 
 
 def fast_track_able(task):
@@ -928,3 +943,65 @@ def remove_agent_url(node):
     info = node.driver_internal_info
     info.pop('agent_url', None)
     node.driver_internal_info = info
+
+
+def _get_node_next_steps(task, step_type, skip_current_step=True):
+    """Get the task's node's next steps.
+
+    This determines what the next (remaining) steps are, and
+    returns the index into the steps list that corresponds to the
+    next step. The remaining steps are determined as follows:
+
+    * If no steps have been started yet, all the steps
+      must be executed
+    * If skip_current_step is False, the remaining steps start
+      with the current step. Otherwise, the remaining steps
+      start with the step after the current one.
+
+    All the steps are in node.driver_internal_info['<step_type>_steps'].
+    node.<step_type>_step is the current step that was just executed
+    (or None, {} if no steps have been executed yet).
+    node.driver_internal_info['<step_type>_step_index'] is the index
+    index into the steps list (or None, doesn't exist if no steps have
+    been executed yet) and corresponds to node.<step_type>_step.
+
+    :param task: A TaskManager object
+    :param step_type: The type of steps to process: 'clean' or 'deploy'.
+    :param skip_current_step: True to skip the current step; False to
+                              include it.
+    :returns: index of the next step; None if there are none to execute.
+
+    """
+    valid_types = set(['clean', 'deploy'])
+    if step_type not in valid_types:
+        # NOTE(rloo): No need to i18n this, since this would be a
+        # developer error; it isn't user-facing.
+        raise exception.Invalid(
+            'step_type must be one of %(valid)s, not %(step)s'
+            % {'valid': valid_types, 'step': step_type})
+    node = task.node
+    if not getattr(node, '%s_step' % step_type):
+        # first time through, all steps need to be done. Return the
+        # index of the first step in the list.
+        return 0
+
+    ind = node.driver_internal_info.get('%s_step_index' % step_type)
+    if ind is None:
+        return None
+
+    if skip_current_step:
+        ind += 1
+    if ind >= len(node.driver_internal_info['%s_steps' % step_type]):
+        # no steps left to do
+        ind = None
+    return ind
+
+
+def get_node_next_clean_steps(task, skip_current_step=True):
+    return _get_node_next_steps(task, 'clean',
+                                skip_current_step=skip_current_step)
+
+
+def get_node_next_deploy_steps(task, skip_current_step=True):
+    return _get_node_next_steps(task, 'deploy',
+                                skip_current_step=skip_current_step)
