@@ -90,16 +90,18 @@ opts = [
                        'cleaning, or rescue. This is done without IP '
                        'addresses assigned to the port, and may be useful '
                        'in some bonded network configurations.')),
-    cfg.IntOpt('dhcpv6_stateful_address_count',
-               default=1,
-               help=_('Number of IPv6 addresses to allocate for ports created '
-                      'for provisioning, cleaning, rescue or inspection on '
-                      'DHCPv6-stateful networks. Different stages of the '
-                      'chain-loading process will request addresses with '
-                      'different CLID/IAID. Due to non-identical identifiers '
-                      'multiple addresses must be reserved for the host to '
-                      'ensure each step of the boot process can successfully '
-                      'lease addresses.'))
+    cfg.StrOpt('inspection_network',
+               help=_('Neutron network UUID or name for the ramdisk to be '
+                      'booted into for in-band inspection of nodes. '
+                      'If a name is provided, it must be unique among all '
+                      'networks or inspection will fail.')),
+    cfg.ListOpt('inspection_network_security_groups',
+                default=[],
+                help=_('List of Neutron Security Group UUIDs to be applied '
+                       'during the node inspection process. Optional for the '
+                       '"neutron" network interface and not used for the '
+                       '"flat" or "noop" network interfaces. If not '
+                       'specified, the default security group is used.')),
 ]
 
 
