@@ -149,6 +149,12 @@ def add_port_filter_by_node(query, value):
         return query.filter(models.Node.uuid == value)
 
 
+def add_port_filter_by_node_owner(query, value):
+    query = query.join(models.Node,
+                       models.Port.node_id == models.Node.id)
+    return query.filter(models.Node.owner == value)
+
+
 def add_portgroup_filter(query, value):
     """Adds a portgroup-specific filter to a query.
 
@@ -279,9 +285,10 @@ def _zip_matching(a, b, key):
 class Connection(api.Connection):
     """SqlAlchemy connection."""
 
-    _NODE_QUERY_FIELDS = {'console_enabled', 'maintenance', 'driver',
-                          'resource_class', 'provision_state', 'uuid', 'id',
-                          'fault', 'conductor_group', 'owner'}
+    _NODE_QUERY_FIELDS = {'console_enabled', 'maintenance', 'retired',
+                          'driver', 'resource_class', 'provision_state',
+                          'uuid', 'id', 'fault', 'conductor_group',
+                          'owner'}
     _NODE_IN_QUERY_FIELDS = {'%s_in' % field: field
                              for field in ('uuid', 'provision_state')}
     _NODE_NON_NULL_FILTERS = {'associated': 'instance_uuid',
@@ -354,7 +361,7 @@ class Connection(api.Connection):
         if filters is None:
             filters = dict()
         supported_filters = {'state', 'resource_class', 'node_uuid',
-                             'conductor_affinity'}
+                             'conductor_affinity', 'owner'}
         unsupported_filters = set(filters).difference(supported_filters)
         if unsupported_filters:
             msg = _("SqlAlchemy API does not support "
@@ -671,29 +678,38 @@ class Connection(api.Connection):
         except NoResultFound:
             raise exception.PortNotFound(port=port_uuid)
 
-    def get_port_by_address(self, address):
+    def get_port_by_address(self, address, owner=None):
         query = model_query(models.Port).filter_by(address=address)
+        if owner:
+            query = add_port_filter_by_node_owner(query, owner)
         try:
             return query.one()
         except NoResultFound:
             raise exception.PortNotFound(port=address)
 
     def get_port_list(self, limit=None, marker=None,
-                      sort_key=None, sort_dir=None):
+                      sort_key=None, sort_dir=None, owner=None):
+        query = model_query(models.Port)
+        if owner:
+            query = add_port_filter_by_node_owner(query, owner)
         return _paginate_query(models.Port, limit, marker,
-                               sort_key, sort_dir)
+                               sort_key, sort_dir, query)
 
     def get_ports_by_node_id(self, node_id, limit=None, marker=None,
-                             sort_key=None, sort_dir=None):
+                             sort_key=None, sort_dir=None, owner=None):
         query = model_query(models.Port)
         query = query.filter_by(node_id=node_id)
+        if owner:
+            query = add_port_filter_by_node_owner(query, owner)
         return _paginate_query(models.Port, limit, marker,
                                sort_key, sort_dir, query)
 
     def get_ports_by_portgroup_id(self, portgroup_id, limit=None, marker=None,
-                                  sort_key=None, sort_dir=None):
+                                  sort_key=None, sort_dir=None, owner=None):
         query = model_query(models.Port)
         query = query.filter_by(portgroup_id=portgroup_id)
+        if owner:
+            query = add_port_filter_by_node_owner(query, owner)
         return _paginate_query(models.Port, limit, marker,
                                sort_key, sort_dir, query)
 
@@ -983,9 +999,9 @@ class Connection(api.Connection):
         nodes = []
         with _session_for_write():
             query = (model_query(models.Node)
-                     .filter(models.Node.reservation.ilike(hostname)))
+                     .filter_by(reservation=hostname))
             nodes = [node['uuid'] for node in query]
-            query.update({'reservation': None}, synchronize_session=False)
+            query.update({'reservation': None})
 
         if nodes:
             nodes = ', '.join(nodes)
@@ -998,14 +1014,13 @@ class Connection(api.Connection):
         nodes = []
         with _session_for_write():
             query = (model_query(models.Node)
-                     .filter(models.Node.reservation.ilike(hostname)))
+                     .filter_by(reservation=hostname))
             query = query.filter(models.Node.target_power_state != sql.null())
             nodes = [node['uuid'] for node in query]
             query.update({'target_power_state': None,
                           'last_error': _("Pending power operation was "
                                           "aborted due to conductor "
-                                          "restart")},
-                         synchronize_session=False)
+                                          "restart")})
 
         if nodes:
             nodes = ', '.join(nodes)
@@ -1495,12 +1510,12 @@ class Connection(api.Connection):
             per-node trait limit.
         """
         if num_traits > MAX_TRAITS_PER_NODE:
-            msg = (_("Could not modify traits for node %(node_id)s as it "
-                     "would exceed the maximum number of traits per node "
-                     "(%(num_traits)d vs. %(max_traits)d)")
-                   % {'node_id': node_id, 'num_traits': num_traits,
-                      'max_traits': MAX_TRAITS_PER_NODE})
-            raise exception.InvalidParameterValue(err=msg)
+            msg = _("Could not modify traits for node %(node_id)s as it would "
+                    "exceed the maximum number of traits per node "
+                    "(%(num_traits)d vs. %(max_traits)d)")
+            raise exception.InvalidParameterValue(
+                msg, node_id=node_id, num_traits=num_traits,
+                max_traits=MAX_TRAITS_PER_NODE)
 
     @oslo_db_api.retry_on_deadlock
     def set_node_traits(self, node_id, traits, version):
