@@ -19,11 +19,11 @@ SQLAlchemy models for baremetal data.
 """
 
 from os import path
+from urllib import parse as urlparse
 
 from oslo_db import options as db_options
 from oslo_db.sqlalchemy import models
 from oslo_db.sqlalchemy import types as db_types
-import six.moves.urllib.parse as urlparse
 from sqlalchemy import Boolean, Column, DateTime, false, Index
 from sqlalchemy import ForeignKey, Integer
 from sqlalchemy import schema, String, Text
@@ -193,6 +193,9 @@ class Node(Base):
     network_interface = Column(String(255), nullable=True)
     raid_interface = Column(String(255), nullable=True)
     rescue_interface = Column(String(255), nullable=True)
+    retired = Column(Boolean, nullable=True, default=False,
+                     server_default=false())
+    retired_reason = Column(Text, nullable=True)
     storage_interface = Column(String(255), nullable=True)
     power_interface = Column(String(255), nullable=True)
     vendor_interface = Column(String(255), nullable=True)
@@ -340,6 +343,7 @@ class Allocation(Base):
     name = Column(String(255), nullable=True)
     node_id = Column(Integer, ForeignKey('nodes.id'), nullable=True)
     state = Column(String(15), nullable=False)
+    owner = Column(String(255), nullable=True)
     last_error = Column(Text, nullable=True)
     resource_class = Column(String(80), nullable=True)
     traits = Column(db_types.JsonEncodedList)
