@@ -12,12 +12,12 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+from urllib import parse as urlparse
+
 from ironic_lib import metrics_utils
-from ironic_lib import utils as il_utils
 from oslo_log import log
 from oslo_utils import excutils
 from oslo_utils import units
-import six.moves.urllib_parse as urlparse
 
 from ironic.common import dhcp_factory
 from ironic.common import exception
@@ -184,13 +184,17 @@ class AgentDeployMixin(agent_base_vendor.AgentDeployMixin):
         if not commands:
             return False
 
-        try:
-            last_command = next(cmd for cmd in reversed(commands)
-                                if cmd['command_name'] == 'prepare_image')
-        except StopIteration:
+        last_command = commands[-1]
+
+        if last_command['command_name'] != 'prepare_image':
+            # catches race condition where prepare_image is still processing
+            # so deploy hasn't started yet
             return False
-        else:
-            return last_command['command_status'] != 'RUNNING'
+
+        if last_command['command_status'] != 'RUNNING':
+            return True
+
+        return False
 
     @METRICS.timer('AgentDeployMixin.continue_deploy')
     @task_manager.require_exclusive_lock
@@ -426,15 +430,7 @@ class AgentDeploy(AgentDeployMixin, base.DeployInterface):
 
         check_image_size(task, image_source)
         # Validate the root device hints
-        try:
-            root_device = node.properties.get('root_device')
-            il_utils.parse_root_device_hints(root_device)
-        except ValueError as e:
-            raise exception.InvalidParameterValue(
-                _('Failed to validate the root device hints for node '
-                  '%(node)s. Error: %(error)s') % {'node': node.uuid,
-                                                   'error': e})
-
+        deploy_utils.get_root_device_for_deploy(node)
         validate_image_proxies(node)
 
     @METRICS.timer('AgentDeploy.deploy')
@@ -458,7 +454,6 @@ class AgentDeploy(AgentDeployMixin, base.DeployInterface):
             # the state machine state going from DEPLOYWAIT -> DEPLOYING
             task.process_event('wait')
             self.continue_deploy(task)
-            return states.DEPLOYWAIT
         elif task.driver.storage.should_write_image(task):
             # Check if the driver has already performed a reboot in a previous
             # deploy step.
@@ -475,12 +470,9 @@ class AgentDeploy(AgentDeployMixin, base.DeployInterface):
             # This is not being done now as it is expected to be
             # refactored in the near future.
             manager_utils.node_power_action(task, states.POWER_OFF)
-            power_state_to_restore = (
-                manager_utils.power_on_node_if_needed(task))
-            task.driver.network.remove_provisioning_network(task)
-            task.driver.network.configure_tenant_networks(task)
-            manager_utils.restore_power_state_if_needed(
-                task, power_state_to_restore)
+            with manager_utils.power_state_for_network_configuration(task):
+                task.driver.network.remove_provisioning_network(task)
+                task.driver.network.configure_tenant_networks(task)
             task.driver.boot.prepare_instance(task)
             manager_utils.node_power_action(task, states.POWER_ON)
             LOG.info('Deployment to node %s done', task.node.uuid)
@@ -504,13 +496,11 @@ class AgentDeploy(AgentDeployMixin, base.DeployInterface):
         manager_utils.node_power_action(task, states.POWER_OFF)
         task.driver.storage.detach_volumes(task)
         deploy_utils.tear_down_storage_configuration(task)
-        power_state_to_restore = manager_utils.power_on_node_if_needed(task)
-        task.driver.network.unconfigure_tenant_networks(task)
-        # NOTE(mgoddard): If the deployment was unsuccessful the node may have
-        # ports on the provisioning network which were not deleted.
-        task.driver.network.remove_provisioning_network(task)
-        manager_utils.restore_power_state_if_needed(
-            task, power_state_to_restore)
+        with manager_utils.power_state_for_network_configuration(task):
+            task.driver.network.unconfigure_tenant_networks(task)
+            # NOTE(mgoddard): If the deployment was unsuccessful the node may
+            # have ports on the provisioning network which were not deleted.
+            task.driver.network.remove_provisioning_network(task)
         return states.DELETED
 
     @METRICS.timer('AgentDeploy.prepare')
@@ -850,11 +840,9 @@ class AgentRescue(base.RescueInterface):
         task.node.save()
 
         task.driver.boot.clean_up_instance(task)
-        power_state_to_restore = manager_utils.power_on_node_if_needed(task)
-        task.driver.network.unconfigure_tenant_networks(task)
-        task.driver.network.add_rescuing_network(task)
-        manager_utils.restore_power_state_if_needed(
-            task, power_state_to_restore)
+        with manager_utils.power_state_for_network_configuration(task):
+            task.driver.network.unconfigure_tenant_networks(task)
+            task.driver.network.add_rescuing_network(task)
         if CONF.agent.manage_agent_boot:
             ramdisk_opts = deploy_utils.build_agent_options(task.node)
             # prepare_ramdisk will set the boot device
@@ -889,10 +877,8 @@ class AgentRescue(base.RescueInterface):
         task.node.save()
 
         self.clean_up(task)
-        power_state_to_restore = manager_utils.power_on_node_if_needed(task)
-        task.driver.network.configure_tenant_networks(task)
-        manager_utils.restore_power_state_if_needed(
-            task, power_state_to_restore)
+        with manager_utils.power_state_for_network_configuration(task):
+            task.driver.network.configure_tenant_networks(task)
         task.driver.boot.prepare_instance(task)
         manager_utils.node_power_action(task, states.POWER_ON)
 
@@ -944,7 +930,5 @@ class AgentRescue(base.RescueInterface):
         manager_utils.remove_node_rescue_password(task.node, save=True)
         if CONF.agent.manage_agent_boot:
             task.driver.boot.clean_up_ramdisk(task)
-        power_state_to_restore = manager_utils.power_on_node_if_needed(task)
-        task.driver.network.remove_rescuing_network(task)
-        manager_utils.restore_power_state_if_needed(
-            task, power_state_to_restore)
+        with manager_utils.power_state_for_network_configuration(task):
+            task.driver.network.remove_rescuing_network(task)
