@@ -27,6 +27,7 @@ import retrying
 from ironic.common import boot_devices
 from ironic.common import exception
 from ironic.common.i18n import _
+from ironic.common import image_service
 from ironic.common import states
 from ironic.conductor import steps as conductor_steps
 from ironic.conductor import utils as manager_utils
@@ -465,10 +466,8 @@ class HeartbeatMixin(object):
                                                   reason=fail_reason)
         task.process_event('resume')
         task.driver.rescue.clean_up(task)
-        power_state_to_restore = manager_utils.power_on_node_if_needed(task)
-        task.driver.network.configure_tenant_networks(task)
-        manager_utils.restore_power_state_if_needed(
-            task, power_state_to_restore)
+        with manager_utils.power_state_for_network_configuration(task):
+            task.driver.network.configure_tenant_networks(task)
         task.process_event('done')
 
 
@@ -585,7 +584,6 @@ class AgentDeployMixin(HeartbeatMixin):
                     'err': command.get('command_error'),
                     'step': node.clean_step})
             LOG.error(msg)
-            driver_utils.collect_ramdisk_logs(task.node, label='cleaning')
             return manager_utils.cleaning_error_handler(task, msg)
         elif command.get('command_status') == 'CLEAN_VERSION_MISMATCH':
             # Cache the new clean steps (and 'hardware_manager_version')
@@ -650,8 +648,6 @@ class AgentDeployMixin(HeartbeatMixin):
                             'cls': e.__class__.__name__,
                             'step': node.clean_step})
                     LOG.exception(msg)
-                    driver_utils.collect_ramdisk_logs(task.node,
-                                                      label='cleaning')
                     return manager_utils.cleaning_error_handler(task, msg)
 
             if task.node.clean_step.get('reboot_requested'):
@@ -668,7 +664,6 @@ class AgentDeployMixin(HeartbeatMixin):
                     'err': command.get('command_status'),
                     'step': node.clean_step})
             LOG.error(msg)
-            driver_utils.collect_ramdisk_logs(task.node, label='cleaning')
             return manager_utils.cleaning_error_handler(task, msg)
 
     @METRICS.timer('AgentDeployMixin.reboot_and_finish_deploy')
@@ -707,25 +702,16 @@ class AgentDeployMixin(HeartbeatMixin):
             if not oob_power_off:
                 try:
                     self._client.power_off(node)
+                    _wait_until_powered_off(task)
                 except Exception as e:
-                    LOG.warning('Failed to soft power off node %(node_uuid)s. '
+                    LOG.warning('Failed to soft power off node %(node_uuid)s '
+                                'in at least %(timeout)d seconds. '
                                 '%(cls)s: %(error)s',
                                 {'node_uuid': node.uuid,
+                                 'timeout': (wait * (attempts - 1)) / 1000,
                                  'cls': e.__class__.__name__, 'error': e},
                                 exc_info=not isinstance(
                                     e, exception.IronicException))
-
-                # NOTE(dtantsur): in rare cases it may happen that the power
-                # off request comes through but we never receive the response.
-                # Check the power state before trying to force off.
-                try:
-                    _wait_until_powered_off(task)
-                except Exception:
-                    LOG.warning('Failed to soft power off node %(node_uuid)s '
-                                'in at least %(timeout)d seconds. Forcing '
-                                'hard power off and proceeding.',
-                                {'node_uuid': node.uuid,
-                                 'timeout': (wait * (attempts - 1)) / 1000})
                     manager_utils.node_power_action(task, states.POWER_OFF)
             else:
                 # Flush the file system prior to hard rebooting the node
@@ -750,12 +736,9 @@ class AgentDeployMixin(HeartbeatMixin):
             log_and_raise_deployment_error(task, msg, exc=e)
 
         try:
-            power_state_to_restore = (
-                manager_utils.power_on_node_if_needed(task))
-            task.driver.network.remove_provisioning_network(task)
-            task.driver.network.configure_tenant_networks(task)
-            manager_utils.restore_power_state_if_needed(
-                task, power_state_to_restore)
+            with manager_utils.power_state_for_network_configuration(task):
+                task.driver.network.remove_provisioning_network(task)
+                task.driver.network.configure_tenant_networks(task)
             manager_utils.node_power_action(task, states.POWER_ON)
         except Exception as e:
             msg = (_('Error rebooting node %(node)s after deploy. '
@@ -841,9 +824,33 @@ class AgentDeployMixin(HeartbeatMixin):
                 LOG.debug('Node %s has a Software RAID configuration',
                           node.uuid)
                 software_raid = True
-                root_uuid = internal_info.get('root_uuid_or_disk_id')
                 break
 
+        # For software RAID try to get the UUID of the root fs from the
+        # image's metadata (via Glance). Fall back to the driver internal
+        # info in case it is not available (e.g. not set or there's no Glance).
+        if software_raid:
+            image_source = node.instance_info.get('image_source')
+            try:
+                context = task.context
+                context.is_admin = True
+                glance = image_service.GlanceImageService(
+                    context=context)
+                image_info = glance.show(image_source)
+                image_properties = image_info.get('properties')
+                root_uuid = image_properties['rootfs_uuid']
+                LOG.debug('Got rootfs_uuid from Glance: %s '
+                          '(node %s)', root_uuid, node.uuid)
+            except Exception as e:
+                LOG.warning('Could not get \'rootfs_uuid\' property for '
+                            'image %(image)s from Glance for node %(node)s. '
+                            '%(cls)s: %(error)s.',
+                            {'image': image_source, 'node': node.uuid,
+                             'cls': e.__class__.__name__, 'error': e})
+                root_uuid = internal_info.get('root_uuid_or_disk_id')
+                LOG.debug('Got rootfs_uuid from driver internal info: '
+                          '%s (node %s)', root_uuid, node.uuid)
+
         # For whole disk images it is not necessary that the root_uuid
         # be provided since the bootloaders on the disk will be used
         whole_disk_image = internal_info.get('is_whole_disk_image')
