@@ -29,7 +29,6 @@ from oslo_utils import excutils
 from oslo_utils import fileutils
 from oslo_utils import netutils
 from oslo_utils import strutils
-import six
 
 from ironic.common import exception
 from ironic.common import faults
@@ -88,15 +87,6 @@ def _get_ironic_session():
     return _IRONIC_SESSION
 
 
-# TODO(dtantsur): just use CONF.iscsi.verify_attempts when
-# iscsi_verify_attempts is removed from ironic-lib.
-def _iscsi_verify_attempts():
-    # Be prepared for eventual removal, hardcode the default of 3
-    return (getattr(CONF.disk_utils, 'iscsi_verify_attempts', 3)
-            if CONF.iscsi.verify_attempts is None
-            else CONF.iscsi.verify_attempts)
-
-
 def _wrap_ipv6(ip):
     if netutils.is_valid_ipv6(ip):
         return "[%s]" % ip
@@ -126,7 +116,7 @@ def get_ironic_api_url():
         raise exception.InvalidParameterValue(_(
             "Couldn't get the URL of the Ironic API service from the "
             "configuration file or keystone catalog. Keystone error: "
-            "%s") % six.text_type(e))
+            "%s") % str(e))
     # NOTE: we should strip '/' from the end because it might be used in
     # hardcoded ramdisk script
     ironic_api = ironic_api.rstrip('/')
@@ -194,7 +184,7 @@ def check_file_system_for_iscsi_device(portal_address,
     check_dir = "/dev/disk/by-path/ip-%s:%s-iscsi-%s-lun-1" % (portal_address,
                                                                portal_port,
                                                                target_iqn)
-    total_checks = _iscsi_verify_attempts()
+    total_checks = CONF.iscsi.verify_attempts
     for attempt in range(total_checks):
         if os.path.exists(check_dir):
             break
@@ -218,7 +208,7 @@ def verify_iscsi_connection(target_iqn):
     """Verify iscsi connection."""
     LOG.debug("Checking for iSCSI target to become active.")
 
-    total_checks = _iscsi_verify_attempts()
+    total_checks = CONF.iscsi.verify_attempts
     for attempt in range(total_checks):
         out, _err = utils.execute('iscsiadm',
                                   '-m', 'node',
@@ -867,10 +857,31 @@ def get_boot_option(node):
     :returns: A string representing the boot option type. Defaults to
         'netboot'.
     """
+
+    # NOTE(TheJulia): Software raid always implies local deployment
+    if is_software_raid(node):
+        return 'local'
     capabilities = utils.parse_instance_info_capabilities(node)
     return capabilities.get('boot_option', get_default_boot_option()).lower()
 
 
+def is_software_raid(node):
+    """Determine if software raid is in use for the deployment.
+
+    :param node: A single Node.
+    :returns: A boolean value of True when software raid is in use,
+              otherwise False
+    """
+    target_raid_config = node.target_raid_config
+    logical_disks = target_raid_config.get('logical_disks', [])
+    software_raid = False
+    for logical_disk in logical_disks:
+        if logical_disk.get('controller') == 'software':
+            software_raid = True
+            break
+    return software_raid
+
+
 def build_agent_options(node):
     """Build the options to be passed to the agent ramdisk.
 
@@ -1289,22 +1300,19 @@ def build_instance_info_for_deploy(task):
                                                  force_raw=force_raw)
             if force_raw:
                 instance_info['image_disk_format'] = 'raw'
-                # Standard behavior is for image_checksum to be MD5,
-                # so if the hash algorithm is None, then we will use
-                # sha256.
-                os_hash_algo = image_info.get('os_hash_algo')
-                if os_hash_algo == 'md5':
-                    LOG.debug('Checksum calculation for image %(image)s is '
-                              'set to \'%(algo)s\', changing to \'sha256\'',
-                              {'algo': os_hash_algo,
-                               'image': image_path})
-                    os_hash_algo = 'sha256'
+
                 LOG.debug('Recalculating checksum for image %(image)s due to '
                           'image conversion.', {'image': image_path})
-                instance_info['image_checksum'] = 'md5-not-supported'
-                hash_value = compute_image_checksum(image_path, os_hash_algo)
-                instance_info['image_os_hash_algo'] = os_hash_algo
-                instance_info['image_os_hash_value'] = hash_value
+                md5checksum = compute_image_checksum(image_path, 'md5')
+                instance_info['image_checksum'] = md5checksum
+                # Populate instance_info with os_hash_algo, os_hash_value
+                # if they exists and not md5
+                os_hash_algo = image_info['os_hash_algo']
+                if os_hash_algo and os_hash_algo != 'md5':
+                    hash_value = compute_image_checksum(image_path,
+                                                        os_hash_algo)
+                    instance_info['image_os_hash_algo'] = os_hash_algo
+                    instance_info['image_os_hash_value'] = hash_value
             else:
                 instance_info['image_checksum'] = image_info['checksum']
                 instance_info['image_disk_format'] = image_info['disk_format']
@@ -1513,3 +1521,27 @@ def set_async_step_flags(node, reboot=None, skip_current_step=None,
         info[fields['polling']] = polling
     node.driver_internal_info = info
     node.save()
+
+
+def get_root_device_for_deploy(node):
+    """Get a root device requested for deployment or None.
+
+    :raises: InvalidParameterValue on invalid hints.
+    :return: Parsed root device hints or None if no hints were provided.
+    """
+    hints = node.instance_info.get('root_device')
+    if not hints:
+        hints = node.properties.get('root_device')
+        if not hints:
+            return
+        source = 'properties'
+    else:
+        source = 'instance_info'
+
+    try:
+        return il_utils.parse_root_device_hints(hints)
+    except ValueError as e:
+        raise exception.InvalidParameterValue(
+            _('Failed to validate the root device hints %(hints)s (from the '
+              'node\'s %(source)s) for node %(node)s. Error: %(error)s') %
+            {'node': node.uuid, 'hints': hints, 'source': source, 'error': e})
