@@ -377,8 +377,7 @@ def commit_config(node, raid_controller, reboot=False, realtime=False):
 
 
 def _change_physical_disk_mode(node, mode=None,
-                               controllers_to_physical_disk_ids=None,
-                               substep="completed"):
+                               controllers_to_physical_disk_ids=None):
     """Physical drives conversion from RAID to JBOD or vice-versa.
 
     :param node: an ironic node object.
@@ -392,25 +391,16 @@ def _change_physical_disk_mode(node, mode=None,
         node, mode, controllers_to_physical_disk_ids)
 
     controllers = list()
-    if 'conversion_results' in change_disk_state:
-        conversion_results = change_disk_state['conversion_results']
-        for controller_id, result in conversion_results.items():
-            controller = {'raid_controller': controller_id,
-                          'is_reboot_required': result['is_reboot_required'],
-                          'is_commit_required': result['is_commit_required']}
-            controllers.append(controller)
-    else:
-        controller_ids = change_disk_state['commit_required_ids']
-        for controller_id in controller_ids:
-            controller = {'raid_controller': controller_id,
-                          'is_reboot_required':
-                          change_disk_state['is_reboot_required'],
-                          'is_commit_required': True}
-            controllers.append(controller)
+    conversion_results = change_disk_state['conversion_results']
+    for controller_id, result in conversion_results.items():
+        controller = {'raid_controller': controller_id,
+                      'is_reboot_required': result['is_reboot_required'],
+                      'is_commit_required': result['is_commit_required']}
+        controllers.append(controller)
 
     return _commit_to_controllers(
         node,
-        controllers, substep=substep)
+        controllers, substep='completed')
 
 
 def abandon_config(node, raid_controller):
@@ -689,7 +679,7 @@ def _calculate_volume_props(logical_disk, physical_disks, free_space_mb):
         error_msg = _('invalid number of physical disks was provided')
         raise exception.DracOperationError(error=error_msg)
 
-    disks_per_span = int(len(selected_disks) / spans_count)
+    disks_per_span = len(selected_disks) / spans_count
 
     # Best practice is to not pass span_length and span_depth when creating a
     # RAID10.  The iDRAC will dynamically calculate these values using maximum
@@ -848,40 +838,6 @@ def _create_config_job(node, controller, reboot=False, realtime=False,
             'raid_config_parameters': raid_config_parameters}
 
 
-def _validate_volume_size(node, logical_disks):
-    new_physical_disks = list_physical_disks(node)
-    free_space_mb = {}
-    new_processed_volumes = []
-    for disk in new_physical_disks:
-        free_space_mb[disk] = disk.free_size_mb
-
-    for logical_disk in logical_disks:
-        selected_disks = [disk for disk in new_physical_disks
-                          if disk.id in logical_disk['physical_disks']]
-
-        spans_count = _calculate_spans(
-            logical_disk['raid_level'], len(selected_disks))
-
-        new_max_vol_size_mb = _max_volume_size_mb(
-            logical_disk['raid_level'],
-            selected_disks,
-            free_space_mb,
-            spans_count=spans_count)
-
-        if logical_disk['size_mb'] > new_max_vol_size_mb:
-            logical_disk['size_mb'] = new_max_vol_size_mb
-            LOG.info("Logical size does not match so calculating volume "
-                     "properties for current logical_disk")
-            _calculate_volume_props(
-                logical_disk, new_physical_disks, free_space_mb)
-            new_processed_volumes.append(logical_disk)
-
-    if new_processed_volumes:
-        return new_processed_volumes
-
-    return logical_disks
-
-
 def _commit_to_controllers(node, controllers, substep="completed"):
     """Commit changes to RAID controllers on the node.
 
@@ -970,40 +926,6 @@ def _commit_to_controllers(node, controllers, substep="completed"):
     return deploy_utils.get_async_step_return_state(node)
 
 
-def _create_virtual_disks(task, node):
-    logical_disks_to_create = node.driver_internal_info[
-        'logical_disks_to_create']
-
-    # Check valid properties attached to voiume after drives conversion
-    isVolValidationNeeded = node.driver_internal_info[
-        'volume_validation']
-    if isVolValidationNeeded:
-        logical_disks_to_create = _validate_volume_size(
-            node, logical_disks_to_create)
-
-    controllers = list()
-    for logical_disk in logical_disks_to_create:
-        controller = dict()
-        controller_cap = create_virtual_disk(
-            node,
-            raid_controller=logical_disk['controller'],
-            physical_disks=logical_disk['physical_disks'],
-            raid_level=logical_disk['raid_level'],
-            size_mb=logical_disk['size_mb'],
-            disk_name=logical_disk.get('name'),
-            span_length=logical_disk.get('span_length'),
-            span_depth=logical_disk.get('span_depth'))
-        controller['raid_controller'] = logical_disk['controller']
-        controller['is_reboot_required'] = controller_cap[
-            'is_reboot_required']
-        controller['is_commit_required'] = controller_cap[
-            'is_commit_required']
-        if controller not in controllers:
-            controllers.append(controller)
-
-    return _commit_to_controllers(node, controllers)
-
-
 def _get_disk_free_size_mb(disk, pending_delete):
     """Return the size of free space on the disk in MB.
 
@@ -1102,7 +1024,9 @@ class DracWSManRAID(base.RAIDInterface):
             del disk['size_gb']
 
         if delete_existing:
-            self._delete_configuration_no_commit(task)
+            controllers = self._delete_configuration_no_commit(task)
+        else:
+            controllers = list()
 
         physical_disks = list_physical_disks(node)
         logical_disks = _find_configuration(logical_disks, physical_disks,
@@ -1122,34 +1046,45 @@ class DracWSManRAID(base.RAIDInterface):
                     logical_disk['controller']].append(
                     physical_disk_name)
 
-        # adding logical_disks to driver_internal_info to create virtual disks
-        driver_internal_info = node.driver_internal_info
-        driver_internal_info[
-            "logical_disks_to_create"] = logical_disks_to_create
-
-        commit_results = None
         if logical_disks_to_create:
             LOG.debug(
                 "Converting physical disks configured to back RAID "
                 "logical disks to RAID mode for node %(node_uuid)s ",
                 {"node_uuid": node.uuid})
-            raid_mode = drac_constants.RaidStatus.raid
-            commit_results = _change_physical_disk_mode(
-                node, raid_mode,
-                controllers_to_physical_disk_ids,
-                substep="create_virtual_disks")
+            raid = drac_constants.RaidStatus.raid
+            _change_physical_disk_mode(
+                node, raid, controllers_to_physical_disk_ids)
 
-        volume_validation = True if commit_results else False
-        driver_internal_info['volume_validation'] = volume_validation
-        node.driver_internal_info = driver_internal_info
-        node.save()
+            LOG.debug("Waiting for physical disk conversion to complete "
+                      "for node %(node_uuid)s. ", {"node_uuid": node.uuid})
+            drac_job.wait_for_job_completion(node)
 
-        if commit_results:
-            return commit_results
-        else:
-            LOG.debug("Controller does not support drives conversion "
-                      "so creating virtual disks")
-            return _create_virtual_disks(task, node)
+            LOG.info(
+                "Completed converting physical disks configured to back RAID "
+                "logical disks to RAID mode for node %(node_uuid)s",
+                {'node_uuid': node.uuid})
+
+        controllers = list()
+        for logical_disk in logical_disks_to_create:
+            controller = dict()
+            controller_cap = create_virtual_disk(
+                node,
+                raid_controller=logical_disk['controller'],
+                physical_disks=logical_disk['physical_disks'],
+                raid_level=logical_disk['raid_level'],
+                size_mb=logical_disk['size_mb'],
+                disk_name=logical_disk.get('name'),
+                span_length=logical_disk.get('span_length'),
+                span_depth=logical_disk.get('span_depth'))
+            controller['raid_controller'] = logical_disk['controller']
+            controller['is_reboot_required'] = controller_cap[
+                'is_reboot_required']
+            controller['is_commit_required'] = controller_cap[
+                'is_commit_required']
+            if controller not in controllers:
+                controllers.append(controller)
+
+        return _commit_to_controllers(node, controllers)
 
     @METRICS.timer('DracRAID.delete_configuration')
     @base.clean_step(priority=0)
@@ -1211,7 +1146,7 @@ class DracWSManRAID(base.RAIDInterface):
                 with task_manager.acquire(context, node_uuid,
                                           purpose=lock_purpose,
                                           shared=True) as task:
-                    if not isinstance(task.driver.raid, DracWSManRAID):
+                    if not isinstance(task.driver.raid, DracRAID):
                         continue
 
                     job_ids = driver_internal_info.get('raid_config_job_ids')
@@ -1263,8 +1198,6 @@ class DracWSManRAID(base.RAIDInterface):
                         return self._convert_drives(task, node)
                 elif substep == 'physical_disk_conversion':
                     self._convert_drives(task, node)
-                elif substep == "create_virtual_disks":
-                    return _create_virtual_disks(task, node)
                 elif substep == 'completed':
                     self._complete_raid_substep(task, node)
             else:
@@ -1397,6 +1330,5 @@ class DracRAID(DracWSManRAID):
     """
 
     def __init__(self):
-        super(DracRAID, self).__init__()
         LOG.warning("RAID interface 'idrac' is deprecated and may be removed "
                     "in a future release. Use 'idrac-wsman' instead.")
