@@ -15,13 +15,13 @@
 iLO Management Interface
 """
 
+from urllib import parse as urlparse
+
 from ironic_lib import metrics_utils
 from oslo_log import log as logging
 from oslo_service import loopingcall
 from oslo_utils import excutils
 from oslo_utils import importutils
-import six
-import six.moves.urllib.parse as urlparse
 
 from ironic.common import boot_devices
 from ironic.common import exception
@@ -418,7 +418,7 @@ class IloManagement(base.ManagementInterface):
         ilo_license_key = kwargs.get('ilo_license_key')
         node = task.node
 
-        if not isinstance(ilo_license_key, six.string_types):
+        if not isinstance(ilo_license_key, str):
             msg = (_("Value of 'ilo_license_key' must be a string instead of "
                      "'%(value)s'. Step 'activate_license' is not executed "
                      "for %(node)s.")
@@ -701,6 +701,13 @@ class Ilo5Management(IloManagement):
         task.node.driver_internal_info = driver_internal_info
         task.node.save()
 
+    def _set_clean_failed(self, task, msg):
+        LOG.error("Out-of-band sanitize disk erase job failed for node "
+                  "%(node)s. Message: '%(message)s'.",
+                  {'node': task.node.uuid, 'message': msg})
+        task.node.last_error = msg
+        task.process_event('fail')
+
     def _wait_for_disk_erase_status(self, node):
         """Wait for out-of-band sanitize disk erase to be completed."""
         interval = CONF.ilo.oob_erase_devices_job_status_interval
@@ -835,4 +842,4 @@ class Ilo5Management(IloManagement):
                                              'ilo_disk_erase_ssd_check',
                                              'cleaning_reboot',
                                              'skip_current_clean_step')
-            manager_utils.cleaning_error_handler(task, ilo_exception)
+            self._set_clean_failed(task, ilo_exception)
