@@ -43,7 +43,6 @@ from oslo_concurrency import processutils
 from oslo_log import log as logging
 from oslo_utils import excutils
 from oslo_utils import strutils
-import six
 
 from ironic.common import boot_devices
 from ironic.common import exception
@@ -110,11 +109,6 @@ OPTIONAL_PROPERTIES = {
                                    '[ipmi]disable_boot_timeout will be '
                                    'used if this option is not set. '
                                    'Optional.'),
-    'ipmi_cipher_suite': _('The number of a cipher suite to use. Only 3 '
-                           '(AES-128 with SHA1) or 17 (AES-128 with SHA256) '
-                           'should ever be used; 17 is preferred. The '
-                           'default value depends on the ipmitool version, '
-                           'some recent versions have switched from 3 to 17.'),
 }
 COMMON_PROPERTIES = REQUIRED_PROPERTIES.copy()
 COMMON_PROPERTIES.update(OPTIONAL_PROPERTIES)
@@ -289,7 +283,7 @@ def _parse_driver_info(node):
 
     address = info.get('ipmi_address')
     username = info.get('ipmi_username')
-    password = six.text_type(info.get('ipmi_password', ''))
+    password = str(info.get('ipmi_password', ''))
     hex_kg_key = info.get('ipmi_hex_kg_key')
     dest_port = info.get('ipmi_port')
     port = info.get('ipmi_terminal_port')
@@ -302,7 +296,6 @@ def _parse_driver_info(node):
     target_address = info.get('ipmi_target_address')
     protocol_version = str(info.get('ipmi_protocol_version', '2.0'))
     force_boot_device = info.get('ipmi_force_boot_device', False)
-    cipher_suite = info.get('ipmi_cipher_suite')
 
     if not username:
         LOG.warning('ipmi_username is not defined or empty for node %s: '
@@ -375,16 +368,6 @@ def _parse_driver_info(node):
         raise exception.InvalidParameterValue(_(
             "Number of ipmi_hex_kg_key characters is not even"))
 
-    if cipher_suite is not None:
-        try:
-            int(cipher_suite)
-        except (TypeError, ValueError):
-            raise exception.InvalidParameterValue(_(
-                "Invalid cipher suite %s, expected a number") % cipher_suite)
-        if protocol_version == '1.5':
-            raise exception.InvalidParameterValue(_(
-                "Cipher suites cannot be used with IPMI 1.5"))
-
     return {
         'address': address,
         'dest_port': dest_port,
@@ -401,7 +384,6 @@ def _parse_driver_info(node):
         'target_address': target_address,
         'protocol_version': protocol_version,
         'force_boot_device': force_boot_device,
-        'cipher_suite': cipher_suite,
     }
 
 
@@ -441,13 +423,17 @@ def _get_ipmitool_args(driver_info, pw_file=None):
             '-L', driver_info['priv_level']
             ]
 
-    for field, arg in [('dest_port', '-p'),
-                       ('username', '-U'),
-                       ('hex_kg_key', '-y'),
-                       ('cipher_suite', '-C')]:
-        if driver_info[field]:
-            args.append(arg)
-            args.append(driver_info[field])
+    if driver_info['dest_port']:
+        args.append('-p')
+        args.append(driver_info['dest_port'])
+
+    if driver_info['username']:
+        args.append('-U')
+        args.append(driver_info['username'])
+
+    if driver_info['hex_kg_key']:
+        args.append('-y')
+        args.append(driver_info['hex_kg_key'])
 
     for name, option in BRIDGING_OPTIONS:
         if driver_info[name] is not None:
@@ -458,7 +444,7 @@ def _get_ipmitool_args(driver_info, pw_file=None):
         args.append('-f')
         args.append(pw_file)
 
-    if CONF.ipmi.debug:
+    if CONF.debug:
         args.append('-v')
 
     # ensure all arguments are strings
@@ -492,10 +478,7 @@ def _exec_ipmitool(driver_info, command, check_exit_code=None,
 
     if _is_option_supported('timing'):
         args.append('-R')
-        if CONF.ipmi.use_ipmitool_retries:
-            args.append(str(num_tries))
-        else:
-            args.append('1')
+        args.append(str(num_tries))
 
         args.append('-N')
         args.append(str(CONF.ipmi.min_command_interval))
@@ -544,13 +527,10 @@ def _exec_ipmitool(driver_info, command, check_exit_code=None,
                         x for x in (
                             IPMITOOL_RETRYABLE_FAILURES +
                             CONF.ipmi.additional_retryable_ipmi_errors)
-                        if x in six.text_type(e)]
-                    # If Ironic is doing retries then retry all errors
-                    retry_failures = (err_list
-                                      or not CONF.ipmi.use_ipmitool_retries)
+                        if x in str(e)]
                     if ((time.time() > end_time)
                         or (num_tries == 0)
-                        or not retry_failures):
+                        or not err_list):
                         LOG.error('IPMI Error while attempting "%(cmd)s" '
                                   'for node %(node)s. Error: %(error)s',
                                   {'node': driver_info['uuid'],
