@@ -19,12 +19,12 @@ iRMC Boot Driver
 import os
 import shutil
 import tempfile
+from urllib import parse as urlparse
 
 from ironic_lib import metrics_utils
 from ironic_lib import utils as ironic_utils
 from oslo_log import log as logging
 from oslo_utils import importutils
-import six.moves.urllib.parse as urlparse
 
 from ironic.common import boot_devices
 from ironic.common import exception
@@ -580,6 +580,8 @@ class IRMCVolumeBootMixIn(object):
     used by VIOM (Virtual I/O Manager) library of SCCI client.
     """
 
+    supported = False
+
     def _validate_volume_boot(self, task):
         """Validate information for volume boot with this interface.
 
@@ -898,6 +900,8 @@ class IRMCVolumeBootMixIn(object):
 class IRMCVirtualMediaBoot(base.BootInterface, IRMCVolumeBootMixIn):
     """iRMC Virtual Media boot-related actions."""
 
+    supported = False
+
     capabilities = ['iscsi_volume_boot', 'fibre_channel_volume_boot']
 
     def __init__(self):
@@ -1094,6 +1098,8 @@ class IRMCVirtualMediaBoot(base.BootInterface, IRMCVolumeBootMixIn):
 class IRMCPXEBoot(pxe.PXEBoot):
     """iRMC PXE boot."""
 
+    supported = False
+
     @METRICS.timer('IRMCPXEBoot.prepare_ramdisk')
     def prepare_ramdisk(self, task, ramdisk_params):
         """Prepares the boot of Ironic ramdisk using PXE.
