@@ -13,12 +13,12 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from urllib import parse as urlparse
+
 from ironic_lib import disk_utils
 from ironic_lib import metrics_utils
-from ironic_lib import utils as il_utils
 from oslo_log import log as logging
 from oslo_utils import excutils
-from six.moves.urllib import parse
 
 from ironic.common import dhcp_factory
 from ironic.common import exception
@@ -284,7 +284,7 @@ def do_agent_iscsi_deploy(task, agent_client):
         deploy_utils.set_failed_state(task, msg)
         raise exception.InstanceDeployFailure(reason=msg)
 
-    address = parse.urlparse(node.driver_internal_info['agent_url'])
+    address = urlparse.urlparse(node.driver_internal_info['agent_url'])
     address = address.hostname
 
     uuid_dict_returned = continue_deploy(task, iqn=iqn, address=address,
@@ -319,14 +319,7 @@ def validate(task):
     # TODO(lucasagomes): Validate the format of the URL
     deploy_utils.get_ironic_api_url()
     # Validate the root device hints
-    try:
-        root_device = task.node.properties.get('root_device')
-        il_utils.parse_root_device_hints(root_device)
-    except ValueError as e:
-        raise exception.InvalidParameterValue(
-            _('Failed to validate the root device hints for node '
-              '%(node)s. Error: %(error)s') % {'node': task.node.uuid,
-                                               'error': e})
+    deploy_utils.get_root_device_for_deploy(task.node)
     deploy_utils.parse_instance_info(task.node)
 
 
@@ -440,12 +433,9 @@ class ISCSIDeploy(AgentDeployMixin, base.DeployInterface):
             # This is not being done now as it is expected to be
             # refactored in the near future.
             manager_utils.node_power_action(task, states.POWER_OFF)
-            power_state_to_restore = (
-                manager_utils.power_on_node_if_needed(task))
-            task.driver.network.remove_provisioning_network(task)
-            task.driver.network.configure_tenant_networks(task)
-            manager_utils.restore_power_state_if_needed(
-                task, power_state_to_restore)
+            with manager_utils.power_state_for_network_configuration(task):
+                task.driver.network.remove_provisioning_network(task)
+                task.driver.network.configure_tenant_networks(task)
             task.driver.boot.prepare_instance(task)
             manager_utils.node_power_action(task, states.POWER_ON)
 
@@ -471,13 +461,11 @@ class ISCSIDeploy(AgentDeployMixin, base.DeployInterface):
         manager_utils.node_power_action(task, states.POWER_OFF)
         task.driver.storage.detach_volumes(task)
         deploy_utils.tear_down_storage_configuration(task)
-        power_state_to_restore = manager_utils.power_on_node_if_needed(task)
-        task.driver.network.unconfigure_tenant_networks(task)
-        # NOTE(mgoddard): If the deployment was unsuccessful the node may have
-        # ports on the provisioning network which were not deleted.
-        task.driver.network.remove_provisioning_network(task)
-        manager_utils.restore_power_state_if_needed(
-            task, power_state_to_restore)
+        with manager_utils.power_state_for_network_configuration(task):
+            task.driver.network.unconfigure_tenant_networks(task)
+            # NOTE(mgoddard): If the deployment was unsuccessful the node may
+            # have ports on the provisioning network which were not deleted.
+            task.driver.network.remove_provisioning_network(task)
         return states.DELETED
 
     @METRICS.timer('ISCSIDeploy.prepare')
