@@ -61,20 +61,7 @@ class PXEBoot(pxe_base.PXEBaseMixin, base.BootInterface):
         if CONF.pxe.ipxe_enabled:
             pxe_utils.create_ipxe_boot_script()
 
-    @METRICS.timer('PXEBoot.validate')
-    def validate(self, task):
-        """Validate the PXE-specific info for booting deploy/instance images.
-
-        This method validates the PXE-specific info for booting the
-        ramdisk and instance on the node.  If invalid, raises an
-        exception; otherwise returns None.
-
-        :param task: a task from TaskManager.
-        :returns: None
-        :raises: InvalidParameterValue, if some parameters are invalid.
-        :raises: MissingParameterValue, if some required parameters are
-            missing.
-        """
+    def _validate_common(self, task):
         node = task.node
 
         if not driver_utils.get_node_mac_addresses(task):
@@ -99,11 +86,29 @@ class PXEBoot(pxe_base.PXEBaseMixin, base.BootInterface):
             validate_boot_parameters_for_trusted_boot(node)
 
         pxe_utils.parse_driver_info(node)
+
+    @METRICS.timer('PXEBoot.validate')
+    def validate(self, task):
+        """Validate the PXE-specific info for booting deploy/instance images.
+
+        This method validates the PXE-specific info for booting the
+        ramdisk and instance on the node.  If invalid, raises an
+        exception; otherwise returns None.
+
+        :param task: a task from TaskManager.
+        :returns: None
+        :raises: InvalidParameterValue, if some parameters are invalid.
+        :raises: MissingParameterValue, if some required parameters are
+            missing.
+        """
+        self._validate_common(task)
+
         # NOTE(TheJulia): If we're not writing an image, we can skip
         # the remainder of this method.
         if (not task.driver.storage.should_write_image(task)):
             return
 
+        node = task.node
         d_info = deploy_utils.get_image_instance_info(node)
         if (node.driver_internal_info.get('is_whole_disk_image')
                 or deploy_utils.get_boot_option(node) == 'local'):
@@ -114,6 +119,20 @@ class PXEBoot(pxe_base.PXEBaseMixin, base.BootInterface):
             props = ['kernel', 'ramdisk']
         deploy_utils.validate_image_properties(task.context, d_info, props)
 
+    @METRICS.timer('PXEBoot.validate_inspection')
+    def validate_inspection(self, task):
+        """Validate that the node has required properties for inspection.
+
+        :param task: A TaskManager instance with the node being checked
+        :raises: UnsupportedDriverExtension
+        """
+        try:
+            self._validate_common(task)
+        except exception.MissingParameterValue:
+            # Fall back to non-managed in-band inspection
+            raise exception.UnsupportedDriverExtension(
+                driver=task.node.driver, extension='inspection')
+
     @METRICS.timer('PXEBoot.prepare_ramdisk')
     def prepare_ramdisk(self, task, ramdisk_params):
         """Prepares the boot of Ironic ramdisk using PXE.
@@ -164,8 +183,11 @@ class PXEBoot(pxe_base.PXEBaseMixin, base.BootInterface):
             boot_mode_utils.sync_boot_mode(task)
 
         pxe_options = pxe_utils.build_pxe_config_options(
-            task, pxe_info, ipxe_enabled=ipxe_enabled)
-        pxe_options.update(ramdisk_params)
+            task, pxe_info, ipxe_enabled=ipxe_enabled,
+            ramdisk_params=ramdisk_params)
+        # TODO(dtantsur): backwards compability hack, remove in the V release
+        if ramdisk_params.get("ipa-api-url"):
+            pxe_options["ipa-api-url"] = ramdisk_params["ipa-api-url"]
 
         pxe_config_template = deploy_utils.get_pxe_config_template(node)
 
@@ -186,6 +208,9 @@ class PXEBoot(pxe_base.PXEBaseMixin, base.BootInterface):
         if pxe_info:
             pxe_utils.cache_ramdisk_kernel(task, pxe_info,
                                            ipxe_enabled=CONF.pxe.ipxe_enabled)
+        LOG.debug('Ramdisk PXE boot for node %(node)s has been prepared '
+                  'with kernel params %(params)s',
+                  {'node': node.uuid, 'params': pxe_options})
 
     @METRICS.timer('PXEBoot.prepare_instance')
     def prepare_instance(self, task):
@@ -332,10 +357,8 @@ class PXERamdiskDeploy(agent.AgentDeploy):
         # IDEA(TheJulia): Maybe a "trusted environment" mode flag
         # that we otherwise fail validation on for drivers that
         # require explicit security postures.
-        power_state_to_restore = manager_utils.power_on_node_if_needed(task)
-        task.driver.network.configure_tenant_networks(task)
-        manager_utils.restore_power_state_if_needed(
-            task, power_state_to_restore)
+        with manager_utils.power_state_for_network_configuration(task):
+            task.driver.network.configure_tenant_networks(task)
 
         # calling boot.prepare_instance will also set the node
         # to PXE boot, and update PXE templates accordingly
