@@ -16,11 +16,11 @@
 import os
 import shutil
 import tempfile
+from urllib import parse as urlparse
 
 from ironic_lib import utils as ironic_utils
 from oslo_log import log
 from oslo_utils import importutils
-from six.moves.urllib import parse as urlparse
 
 from ironic.common import boot_devices
 from ironic.common import exception
@@ -50,11 +50,19 @@ OPTIONAL_PROPERTIES = {
                            "driver should use virtual media Floppy device "
                            "for passing configuration information to the "
                            "ramdisk. Defaults to False. Optional."),
+    'kernel_append_params': _("Additional kernel parameters to pass down to "
+                              "instance kernel. These parameters can be "
+                              "consumed by the kernel or by the applications "
+                              "by reading /proc/cmdline. Mind severe cmdline "
+                              "size limit. Overrides "
+                              "[redfish]/kernel_append_params ironic "
+                              "option."),
     'bootloader': _("URL or Glance UUID  of the EFI system partition "
                     "image containing EFI boot loader. This image will be "
                     "used by ironic when building UEFI-bootable ISO "
                     "out of kernel and ramdisk. Required for UEFI "
-                    "boot from partition images.")
+                    "boot from partition images."),
+
 }
 
 RESCUE_PROPERTIES = {
@@ -431,12 +439,15 @@ class RedfishVirtualMediaBoot(base.BootInterface):
                 "building ISO for %(node)s") %
                 {'node': task.node.uuid})
 
+        i_info = task.node.instance_info
+
         if deploy_utils.get_boot_option(task.node) == "ramdisk":
-            i_info = task.node.instance_info
             kernel_params = "root=/dev/ram0 text "
             kernel_params += i_info.get("ramdisk_kernel_arguments", "")
+
         else:
-            kernel_params = CONF.redfish.kernel_append_params
+            kernel_params = i_info.get(
+                'kernel_append_params', CONF.redfish.kernel_append_params)
 
         if params:
             kernel_params = ' '.join(
@@ -628,6 +639,21 @@ class RedfishVirtualMediaBoot(base.BootInterface):
         if task.driver.storage.should_write_image(task):
             self._validate_instance_info(task)
 
+    def validate_inspection(self, task):
+        """Validate that the node has required properties for inspection.
+
+        :param task: A TaskManager instance with the node being checked
+        :raises: MissingParameterValue if node is missing one or more required
+            parameters
+        :raises: UnsupportedDriverExtension
+        """
+        try:
+            self._validate_driver_info(task)
+        except exception.MissingParameterValue:
+            # Fall back to non-managed in-band inspection
+            raise exception.UnsupportedDriverExtension(
+                driver=task.node.driver, extension='inspection')
+
     def prepare_ramdisk(self, task, ramdisk_params):
         """Prepares the boot of deploy or rescue ramdisk over virtual media.
 
@@ -652,7 +678,8 @@ class RedfishVirtualMediaBoot(base.BootInterface):
         # modify the state of the node due to virtual media operations.
         if node.provision_state not in (states.DEPLOYING,
                                         states.CLEANING,
-                                        states.RESCUING):
+                                        states.RESCUING,
+                                        states.INSPECTING):
             return
 
         manager_utils.node_power_action(task, states.POWER_OFF)
