@@ -20,12 +20,12 @@ from oslo_utils import importutils
 
 from ironic.common import boot_devices
 from ironic.common import boot_modes
+from ironic.common import components
 from ironic.common import exception
 from ironic.common.i18n import _
-from ironic.common import utils
+from ironic.common import indicator_states
 from ironic.conductor import task_manager
 from ironic.drivers import base
-from ironic.drivers.modules import boot_mode_utils
 from ironic.drivers.modules.redfish import utils as redfish_utils
 
 LOG = log.getLogger(__name__)
@@ -57,63 +57,15 @@ if sushy:
     BOOT_DEVICE_PERSISTENT_MAP_REV = {v: k for k, v in
                                       BOOT_DEVICE_PERSISTENT_MAP.items()}
 
+    INDICATOR_MAP = {
+        sushy.INDICATOR_LED_LIT: indicator_states.ON,
+        sushy.INDICATOR_LED_OFF: indicator_states.OFF,
+        sushy.INDICATOR_LED_BLINKING: indicator_states.BLINKING,
+        sushy.INDICATOR_LED_UNKNOWN: indicator_states.UNKNOWN
+    }
 
-def _set_boot_device(task, system, device, persistent=False):
-    """An internal routine to set the boot device.
-
-    :param task: a task from TaskManager.
-    :param system: a Redfish System object.
-    :param device: the Redfish boot device.
-    :param persistent: Boolean value. True if the boot device will
-                       persist to all future boots, False if not.
-                       Default: False.
-    :raises: SushyError on an error from the Sushy library
-    """
-    desired_enabled = BOOT_DEVICE_PERSISTENT_MAP_REV[persistent]
-    current_enabled = system.boot.get('enabled')
-
-    # NOTE(etingof): this can be racy, esp if BMC is not RESTful
-    enabled = (desired_enabled
-               if desired_enabled != current_enabled else None)
-
-    use_new_set_system_boot = True
-
-    try:
-        try:
-            system.set_system_boot_options(device, enabled=enabled)
-        except AttributeError:
-            enabled = desired_enabled
-            use_new_set_system_boot = False
-            system.set_system_boot_source(device, enabled=enabled)
-    except sushy.exceptions.SushyError as e:
-        if enabled == sushy.BOOT_SOURCE_ENABLED_CONTINUOUS:
-            # NOTE(dtantsur): continuous boot device settings have been
-            # removed from Redfish, and some vendors stopped supporting
-            # it before an alternative was provided. As a work around,
-            # use one-time boot and restore the boot device on every
-            # reboot via RedfishPower.
-            LOG.debug('Error %(error)s when trying to set a '
-                      'persistent boot device on node %(node)s, '
-                      'falling back to one-time boot settings',
-                      {'error': e, 'node': task.node.uuid})
-
-            if use_new_set_system_boot:
-                system.set_system_boot_options(
-                    device, enabled=sushy.BOOT_SOURCE_ENABLED_ONCE)
-            else:
-                system.set_system_boot_source(
-                    device, enabled=sushy.BOOT_SOURCE_ENABLED_ONCE)
-
-            LOG.warning('Could not set persistent boot device to '
-                        '%(dev)s for node %(node)s, using one-time '
-                        'boot device instead',
-                        {'dev': device, 'node': task.node.uuid})
-            utils.set_node_nested_field(
-                task.node, 'driver_internal_info',
-                'redfish_boot_device', device)
-            task.node.save()
-        else:
-            raise
+    INDICATOR_MAP_REV = {
+        v: k for k, v in INDICATOR_MAP.items()}
 
 
 class RedfishManagement(base.ManagementInterface):
@@ -155,33 +107,6 @@ class RedfishManagement(base.ManagementInterface):
         """
         return list(BOOT_DEVICE_MAP_REV)
 
-    @task_manager.require_exclusive_lock
-    def restore_boot_device(self, task, system):
-        """Restore boot device if needed.
-
-        Checks the redfish_boot_device internal flag and sets the one-time
-        boot device accordingly. A warning is issued if it fails.
-
-        This method is supposed to be called from the Redfish power interface
-        and should be considered private to the Redfish hardware type.
-
-        :param task: a task from TaskManager.
-        :param system: a Redfish System object.
-        """
-        device = task.node.driver_internal_info.get('redfish_boot_device')
-        if not device:
-            return
-
-        LOG.debug('Restoring boot device %(dev)s on node %(node)s',
-                  {'dev': device, 'node': task.node.uuid})
-        try:
-            _set_boot_device(task, system, device)
-        except sushy.exceptions.SushyError as e:
-            LOG.warning('Unable to recover boot device %(dev)s for node '
-                        '%(node)s, relying on the pre-configured boot order. '
-                        'Error: %(error)s',
-                        {'dev': device, 'node': task.node.uuid, 'error': e})
-
     @task_manager.require_exclusive_lock
     def set_boot_device(self, task, device, persistent=False):
         """Set the boot device for a node.
@@ -199,16 +124,12 @@ class RedfishManagement(base.ManagementInterface):
         :raises: RedfishConnectionError when it fails to connect to Redfish
         :raises: RedfishError on an error from the Sushy library
         """
-        utils.pop_node_nested_field(
-            task.node, 'driver_internal_info', 'redfish_boot_device')
-        task.node.save()
-
         system = redfish_utils.get_system(task.node)
 
         try:
-            _set_boot_device(
-                task, system, BOOT_DEVICE_MAP_REV[device],
-                persistent=persistent)
+            system.set_system_boot_source(
+                BOOT_DEVICE_MAP_REV[device],
+                enabled=BOOT_DEVICE_PERSISTENT_MAP_REV[persistent])
         except sushy.exceptions.SushyError as e:
             error_msg = (_('Redfish set boot device failed for node '
                            '%(node)s. Error: %(error)s') %
@@ -216,10 +137,6 @@ class RedfishManagement(base.ManagementInterface):
             LOG.error(error_msg)
             raise exception.RedfishError(error=error_msg)
 
-        # Ensure that boot mode is synced with what is set.
-        # Some BMCs reset it to default (BIOS) when changing the boot device.
-        boot_mode_utils.sync_boot_mode(task)
-
     def get_boot_device(self, task):
         """Get the current boot device for a node.
 
@@ -271,30 +188,28 @@ class RedfishManagement(base.ManagementInterface):
         :raises: RedfishError on an error from the Sushy library
         """
         system = redfish_utils.get_system(task.node)
-        try:
-            try:
-                system.set_system_boot_options(mode=BOOT_MODE_MAP_REV[mode])
-            except AttributeError:
-                boot_device = system.boot.get('target')
-                if not boot_device:
-                    error_msg = (_('Cannot change boot mode on node %(node)s '
-                                   'because its boot device is not set.') %
-                                 {'node': task.node.uuid})
-                    LOG.error(error_msg)
-                    raise exception.RedfishError(error_msg)
 
-                boot_override = system.boot.get('enabled')
-                if not boot_override:
-                    error_msg = (_('Cannot change boot mode on node %(node)s '
-                                   'because its boot source override is '
-                                   'not set.') %
-                                 {'node': task.node.uuid})
-                    LOG.error(error_msg)
-                    raise exception.RedfishError(error_msg)
-                system.set_system_boot_source(
-                    boot_device,
-                    enabled=boot_override,
-                    mode=BOOT_MODE_MAP_REV[mode])
+        boot_device = system.boot.get('target')
+        if not boot_device:
+            error_msg = (_('Cannot change boot mode on node %(node)s '
+                           'because its boot device is not set.') %
+                         {'node': task.node.uuid})
+            LOG.error(error_msg)
+            raise exception.RedfishError(error_msg)
+
+        boot_override = system.boot.get('enabled')
+        if not boot_override:
+            error_msg = (_('Cannot change boot mode on node %(node)s '
+                           'because its boot source override is not set.') %
+                         {'node': task.node.uuid})
+            LOG.error(error_msg)
+            raise exception.RedfishError(error_msg)
+
+        try:
+            system.set_system_boot_source(
+                boot_device,
+                enabled=boot_override,
+                mode=BOOT_MODE_MAP_REV[mode])
 
         except sushy.exceptions.SushyError as e:
             error_msg = (_('Setting boot mode to %(mode)s '
@@ -490,3 +405,200 @@ class RedfishManagement(base.ManagementInterface):
                                                   'error': e})
             LOG.error(error_msg)
             raise exception.RedfishError(error=error_msg)
+
+    def get_supported_indicators(self, task, component=None):
+        """Get a map of the supported indicators (e.g. LEDs).
+
+        :param task: A task from TaskManager.
+        :param component: If not `None`, return indicator information
+            for just this component, otherwise return indicators for
+            all existing components.
+        :returns: A dictionary of hardware components
+            (:mod:`ironic.common.components`) as keys with values
+            being dictionaries having indicator IDs as keys and indicator
+            properties as values.
+
+            ::
+
+             {
+                 'chassis': {
+                     'enclosure-0': {
+                         "readonly": true,
+                         "states": [
+                             "OFF",
+                             "ON"
+                         ]
+                     }
+                 },
+                 'system':
+                     'blade-A': {
+                         "readonly": true,
+                         "states": [
+                             "OFF",
+                             "ON"
+                         ]
+                     }
+                 },
+                 'drive':
+                     'ssd0': {
+                         "readonly": true,
+                         "states": [
+                             "OFF",
+                             "ON"
+                         ]
+                     }
+                 }
+             }
+        """
+        properties = {
+            "readonly": False,
+            "states": [
+                indicator_states.BLINKING,
+                indicator_states.OFF,
+                indicator_states.ON
+            ]
+        }
+
+        indicators = {}
+
+        system = redfish_utils.get_system(task.node)
+
+        try:
+            if component in (None, components.CHASSIS) and system.chassis:
+                indicators[components.CHASSIS] = {
+                    chassis.uuid: properties for chassis in system.chassis
+                    if chassis.indicator_led
+                }
+
+        except sushy.exceptions.SushyError as e:
+            LOG.debug('Chassis indicator not available for node %(node)s: '
+                      '%(error)s', {'node': task.node.uuid, 'error': e})
+
+        try:
+            if component in (None, components.SYSTEM) and system.indicator_led:
+                indicators[components.SYSTEM] = {
+                    system.uuid: properties
+                }
+
+        except sushy.exceptions.SushyError as e:
+            LOG.debug('System indicator not available for node %(node)s: '
+                      '%(error)s', {'node': task.node.uuid, 'error': e})
+
+        try:
+            if (component in (None, components.DISK) and
+                    system.simple_storage and system.simple_storage.drives):
+                indicators[components.DISK] = {
+                    drive.uuid: properties
+                    for drive in system.simple_storage.drives
+                    if drive.indicator_led
+                }
+
+        except sushy.exceptions.SushyError as e:
+            LOG.debug('Drive indicator not available for node %(node)s: '
+                      '%(error)s', {'node': task.node.uuid, 'error': e})
+
+        return indicators
+
+    def set_indicator_state(self, task, component, indicator, state):
+        """Set indicator on the hardware component to the desired state.
+
+        :param task: A task from TaskManager.
+        :param component: The hardware component, one of
+            :mod:`ironic.common.components`.
+        :param indicator: Indicator ID (as reported by
+            `get_supported_indicators`).
+        :param state: Desired state of the indicator, one of
+            :mod:`ironic.common.indicator_states`.
+        :raises: InvalidParameterValue if an invalid component, indicator
+                 or state is specified.
+        :raises: MissingParameterValue if a required parameter is missing
+        :raises: RedfishError on an error from the Sushy library
+        """
+        system = redfish_utils.get_system(task.node)
+
+        try:
+            if (component == components.SYSTEM
+                    and indicator == system.uuid):
+                system.set_indicator_led(INDICATOR_MAP_REV[state])
+                return
+
+            elif (component == components.CHASSIS
+                    and system.chassis):
+                for chassis in system.chassis:
+                    if chassis.uuid == indicator:
+                        chassis.set_indicator_led(
+                            INDICATOR_MAP_REV[state])
+                        return
+
+            elif (component == components.DISK and
+                  system.simple_storage and system.simple_storage.drives):
+                for drive in system.simple_storage.drives:
+                    if drive.uuid == indicator:
+                        drive.set_indicator_led(
+                            INDICATOR_MAP_REV[state])
+                        return
+
+        except sushy.exceptions.SushyError as e:
+            error_msg = (_('Redfish set %(component)s indicator %(indicator)s '
+                           'state %(state)s failed for node %(node)s. Error: '
+                           '%(error)s') % {'component': component,
+                                           'indicator': indicator,
+                                           'state': state,
+                                           'node': task.node.uuid,
+                                           'error': e})
+            LOG.error(error_msg)
+            raise exception.RedfishError(error=error_msg)
+
+        raise exception.MissingParameterValue(_(
+            "Unknown indicator %(indicator)s for component %(component)s of "
+            "node %(uuid)s") % {'indicator': indicator,
+                                'component': component,
+                                'uuid': task.node.uuid})
+
+    def get_indicator_state(self, task, component, indicator):
+        """Get current state of the indicator of the hardware component.
+
+        :param task: A task from TaskManager.
+        :param component: The hardware component, one of
+            :mod:`ironic.common.components`.
+        :param indicator: Indicator ID (as reported by
+            `get_supported_indicators`).
+        :raises: MissingParameterValue if a required parameter is missing
+        :raises: RedfishError on an error from the Sushy library
+        :returns: Current state of the indicator, one of
+            :mod:`ironic.common.indicator_states`.
+        """
+        system = redfish_utils.get_system(task.node)
+
+        try:
+            if (component == components.SYSTEM
+                    and indicator == system.uuid):
+                return INDICATOR_MAP[system.indicator_led]
+
+            if (component == components.CHASSIS
+                    and system.chassis):
+                for chassis in system.chassis:
+                    if chassis.uuid == indicator:
+                        return INDICATOR_MAP[chassis.indicator_led]
+
+            if (component == components.DISK and
+                    system.simple_storage and system.simple_storage.drives):
+                for drive in system.simple_storage.drives:
+                    if drive.uuid == indicator:
+                        return INDICATOR_MAP[drive.indicator_led]
+
+        except sushy.exceptions.SushyError as e:
+            error_msg = (_('Redfish get %(component)s indicator %(indicator)s '
+                           'state failed for node %(node)s. Error: '
+                           '%(error)s') % {'component': component,
+                                           'indicator': indicator,
+                                           'node': task.node.uuid,
+                                           'error': e})
+            LOG.error(error_msg)
+            raise exception.RedfishError(error=error_msg)
+
+        raise exception.MissingParameterValue(_(
+            "Unknown indicator %(indicator)s for component %(component)s of "
+            "node %(uuid)s") % {'indicator': indicator,
+                                'component': component,
+                                'uuid': task.node.uuid})
