@@ -14,14 +14,13 @@ Tests for the API /deploy_templates/ methods.
 """
 
 import datetime
+from http import client as http_client
+from urllib import parse as urlparse
 
 import mock
 from oslo_config import cfg
 from oslo_utils import timeutils
 from oslo_utils import uuidutils
-import six
-from six.moves import http_client
-from six.moves.urllib import parse as urlparse
 
 from ironic.api.controllers import base as api_base
 from ironic.api.controllers import v1 as api_v1
@@ -207,7 +206,7 @@ class TestListDeployTemplates(BaseDeployTemplatesAPITest):
         self.assertEqual(len(templates), len(data['deploy_templates']))
 
         uuids = [n['uuid'] for n in data['deploy_templates']]
-        six.assertCountEqual(self, templates, uuids)
+        self.assertCountEqual(templates, uuids)
 
     def test_links(self):
         uuid = uuidutils.generate_uuid()
@@ -250,6 +249,23 @@ class TestListDeployTemplates(BaseDeployTemplatesAPITest):
         next_marker = data['deploy_templates'][-1]['uuid']
         self.assertIn(next_marker, data['next'])
 
+    def test_collection_links_custom_fields(self):
+        cfg.CONF.set_override('max_limit', 3, 'api')
+        templates = []
+        fields = 'uuid,steps'
+        for i in range(5):
+            template = obj_utils.create_test_deploy_template(
+                self.context,
+                uuid=uuidutils.generate_uuid(),
+                name='CUSTOM_DT%s' % i)
+            templates.append(template.uuid)
+        data = self.get_json('/deploy_templates?fields=%s' % fields,
+                             headers=self.headers)
+        self.assertEqual(3, len(data['deploy_templates']))
+        next_marker = data['deploy_templates'][-1]['uuid']
+        self.assertIn(next_marker, data['next'])
+        self.assertIn('fields', data['next'])
+
     def test_get_collection_pagination_no_uuid(self):
         fields = 'name'
         limit = 2
@@ -344,7 +360,7 @@ class TestPatch(BaseDeployTemplatesAPITest):
         self.assertEqual('application/json', response.content_type)
         self.assertEqual(http_client.BAD_REQUEST, response.status_code)
         self.assertTrue(response.json['error_message'])
-        self.assertIn(error_msg, response.json['error_message'])
+        self.assertRegex(response.json['error_message'], error_msg)
         self.assertFalse(mock_save.called)
         return response
 
@@ -522,7 +538,8 @@ class TestPatch(BaseDeployTemplatesAPITest):
         }
         patch = [{'path': '/steps/1', 'op': 'replace', 'value': step}]
         self._test_update_bad_request(
-            mock_save, patch, "list assignment index out of range")
+            mock_save, patch, "list assignment index out of range|"
+                              "can't replace outside of list")
 
     def test_replace_empty_step_list_fail(self, mock_save):
         patch = [{'path': '/steps', 'op': 'replace', 'value': []}]
@@ -638,7 +655,7 @@ class TestPatch(BaseDeployTemplatesAPITest):
     def test_add_root_non_existent(self, mock_save):
         patch = [{'path': '/foo', 'value': 'bar', 'op': 'add'}]
         self._test_update_bad_request(
-            mock_save, patch, "Adding a new attribute (/foo)")
+            mock_save, patch, "Adding a new attribute \(/foo\)")
 
     def test_add_too_high_index_step_fail(self, mock_save):
         step = {
