@@ -14,11 +14,12 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from http import client as http_client
+
 import mock
 import os_traits
 from oslo_config import cfg
 from oslo_utils import uuidutils
-from six.moves import http_client
 from webob import static
 import wsme
 
@@ -46,17 +47,17 @@ class TestApiUtils(base.TestCase):
         self.assertEqual(CONF.api.max_limit, limit)
 
         # negative
-        self.assertRaises(wsme.exc.ClientSideError, utils.validate_limit, -1)
+        self.assertRaises(exception.ClientSideError, utils.validate_limit, -1)
 
         # zero
-        self.assertRaises(wsme.exc.ClientSideError, utils.validate_limit, 0)
+        self.assertRaises(exception.ClientSideError, utils.validate_limit, 0)
 
     def test_validate_sort_dir(self):
         sort_dir = utils.validate_sort_dir('asc')
         self.assertEqual('asc', sort_dir)
 
         # invalid sort_dir parameter
-        self.assertRaises(wsme.exc.ClientSideError,
+        self.assertRaises(exception.ClientSideError,
                           utils.validate_sort_dir,
                           'fake-sort')
 
@@ -64,25 +65,25 @@ class TestApiUtils(base.TestCase):
         utils.validate_trait(os_traits.HW_CPU_X86_AVX2)
         utils.validate_trait("CUSTOM_1")
         utils.validate_trait("CUSTOM_TRAIT_GOLD")
-        self.assertRaises(wsme.exc.ClientSideError,
+        self.assertRaises(exception.ClientSideError,
                           utils.validate_trait, "A" * 256)
-        self.assertRaises(wsme.exc.ClientSideError,
+        self.assertRaises(exception.ClientSideError,
                           utils.validate_trait, "CuSTOM_1")
-        self.assertRaises(wsme.exc.ClientSideError,
+        self.assertRaises(exception.ClientSideError,
                           utils.validate_trait, "")
-        self.assertRaises(wsme.exc.ClientSideError,
+        self.assertRaises(exception.ClientSideError,
                           utils.validate_trait, "CUSTOM_bob")
-        self.assertRaises(wsme.exc.ClientSideError,
+        self.assertRaises(exception.ClientSideError,
                           utils.validate_trait, "CUSTOM_1-BOB")
-        self.assertRaises(wsme.exc.ClientSideError,
+        self.assertRaises(exception.ClientSideError,
                           utils.validate_trait, "aCUSTOM_1a")
         large = "CUSTOM_" + ("1" * 248)
         self.assertEqual(255, len(large))
         utils.validate_trait(large)
-        self.assertRaises(wsme.exc.ClientSideError,
+        self.assertRaises(exception.ClientSideError,
                           utils.validate_trait, large + "1")
         # Check custom error prefix.
-        self.assertRaisesRegex(wsme.exc.ClientSideError,
+        self.assertRaisesRegex(exception.ClientSideError,
                                "spongebob",
                                utils.validate_trait, "invalid", "spongebob")
 
@@ -96,7 +97,7 @@ class TestApiUtils(base.TestCase):
     def test_apply_jsonpatch_no_add_root_attr(self):
         doc = {}
         patch = [{"op": "add", "path": "/foo", "value": 42}]
-        self.assertRaisesRegex(wsme.exc.ClientSideError,
+        self.assertRaisesRegex(exception.ClientSideError,
                                "Adding a new attribute",
                                utils.apply_jsonpatch, doc, patch)
 
@@ -113,6 +114,7 @@ class TestApiUtils(base.TestCase):
         doc = []
         patch = [{"op": "replace", "path": "/0", "value": 42}]
         self.assertRaisesRegex(exception.PatchError,
+                               "can't replace outside of list|"
                                "list assignment index out of range",
                                utils.apply_jsonpatch, doc, patch)
 
@@ -479,16 +481,22 @@ class TestCheckAllowFields(base.TestCase):
         mock_request.version.minor = 34
         self.assertFalse(utils.allow_node_rebuild_with_configdrive())
 
+    def test_allow_configdrive_vendor_data(self, mock_request):
+        mock_request.version.minor = 59
+        self.assertTrue(utils.allow_configdrive_vendor_data())
+        mock_request.version.minor = 58
+        self.assertFalse(utils.allow_configdrive_vendor_data())
+
     def test_check_allow_configdrive_fails(self, mock_request):
         mock_request.version.minor = 35
-        self.assertRaises(wsme.exc.ClientSideError,
+        self.assertRaises(exception.ClientSideError,
                           utils.check_allow_configdrive, states.DELETED,
                           "abcd")
-        self.assertRaises(wsme.exc.ClientSideError,
+        self.assertRaises(exception.ClientSideError,
                           utils.check_allow_configdrive, states.ACTIVE,
                           {'meta_data': {}})
         mock_request.version.minor = 34
-        self.assertRaises(wsme.exc.ClientSideError,
+        self.assertRaises(exception.ClientSideError,
                           utils.check_allow_configdrive, states.REBUILD,
                           "abcd")
 
@@ -500,25 +508,36 @@ class TestCheckAllowFields(base.TestCase):
         utils.check_allow_configdrive(states.ACTIVE, "abcd")
 
     def test_check_allow_configdrive_as_dict(self, mock_request):
-        mock_request.version.minor = 56
+        mock_request.version.minor = 59
         utils.check_allow_configdrive(states.ACTIVE, {'meta_data': {}})
         utils.check_allow_configdrive(states.ACTIVE, {'meta_data': {},
                                                       'network_data': {},
-                                                      'user_data': {}})
+                                                      'user_data': {},
+                                                      'vendor_data': {}})
         utils.check_allow_configdrive(states.ACTIVE, {'user_data': 'foo'})
         utils.check_allow_configdrive(states.ACTIVE, {'user_data': ['foo']})
 
+    def test_check_allow_configdrive_vendor_data_failed(self, mock_request):
+        mock_request.version.minor = 58
+        self.assertRaises(exception.ClientSideError,
+                          utils.check_allow_configdrive,
+                          states.ACTIVE,
+                          {'meta_data': {},
+                           'network_data': {},
+                           'user_data': {},
+                           'vendor_data': {}})
+
     def test_check_allow_configdrive_as_dict_invalid(self, mock_request):
-        mock_request.version.minor = 56
-        self.assertRaises(wsme.exc.ClientSideError,
+        mock_request.version.minor = 59
+        self.assertRaises(exception.ClientSideError,
                           utils.check_allow_configdrive, states.REBUILD,
                           {'foo': 'bar'})
         for key in ['meta_data', 'network_data']:
-            self.assertRaises(wsme.exc.ClientSideError,
+            self.assertRaises(exception.ClientSideError,
                               utils.check_allow_configdrive, states.REBUILD,
                               {key: 'a string'})
         for key in ['meta_data', 'network_data', 'user_data']:
-            self.assertRaises(wsme.exc.ClientSideError,
+            self.assertRaises(exception.ClientSideError,
                               utils.check_allow_configdrive, states.REBUILD,
                               {key: 42})
 
@@ -636,7 +655,7 @@ class TestNodeIdent(base.TestCase):
 class TestVendorPassthru(base.TestCase):
 
     def test_method_not_specified(self):
-        self.assertRaises(wsme.exc.ClientSideError,
+        self.assertRaises(exception.ClientSideError,
                           utils.vendor_passthru, 'fake-ident',
                           None, 'fake-topic', data='fake-data')
 
@@ -770,3 +789,401 @@ class TestPortgroupIdent(base.TestCase):
         self.assertRaises(exception.InvalidUuidOrName,
                           utils.get_rpc_portgroup,
                           self.invalid_name)
+
+
+class TestCheckNodePolicy(base.TestCase):
+    def setUp(self):
+        super(TestCheckNodePolicy, self).setUp()
+        self.valid_node_uuid = uuidutils.generate_uuid()
+        self.node = test_api_utils.post_get_test_node()
+        self.node['owner'] = '12345'
+
+    @mock.patch.object(api, 'request', spec_set=["context", "version"])
+    @mock.patch.object(policy, 'authorize', spec=True)
+    def test_check_node_policy(
+            self, mock_authorize, mock_pr
+    ):
+        mock_pr.version.minor = 50
+        mock_pr.context.to_policy_values.return_value = {}
+
+        utils.check_node_policy(
+            'fake_policy', self.node['owner']
+        )
+        mock_authorize.assert_called_once_with(
+            'fake_policy', {'node.owner': '12345'}, {})
+
+    @mock.patch.object(api, 'request', spec_set=["context", "version"])
+    @mock.patch.object(policy, 'authorize', spec=True)
+    def test_check_node_policy_forbidden(
+            self, mock_authorize, mock_pr
+    ):
+        mock_pr.version.minor = 50
+        mock_pr.context.to_policy_values.return_value = {}
+        mock_authorize.side_effect = exception.HTTPForbidden(resource='fake')
+
+        self.assertRaises(
+            exception.HTTPForbidden,
+            utils.check_node_policy,
+            'fake-policy',
+            self.node['owner']
+        )
+
+
+class TestCheckNodePolicyAndRetrieve(base.TestCase):
+    def setUp(self):
+        super(TestCheckNodePolicyAndRetrieve, self).setUp()
+        self.valid_node_uuid = uuidutils.generate_uuid()
+        self.node = test_api_utils.post_get_test_node()
+        self.node['owner'] = '12345'
+
+    @mock.patch.object(api, 'request', spec_set=["context", "version"])
+    @mock.patch.object(policy, 'authorize', spec=True)
+    @mock.patch.object(utils, 'get_rpc_node')
+    @mock.patch.object(utils, 'get_rpc_node_with_suffix')
+    def test_check_node_policy_and_retrieve(
+            self, mock_grnws, mock_grn, mock_authorize, mock_pr
+    ):
+        mock_pr.version.minor = 50
+        mock_pr.context.to_policy_values.return_value = {}
+        mock_grn.return_value = self.node
+
+        rpc_node = utils.check_node_policy_and_retrieve(
+            'fake_policy', self.valid_node_uuid
+        )
+        mock_grn.assert_called_once_with(self.valid_node_uuid)
+        mock_grnws.assert_not_called()
+        mock_authorize.assert_called_once_with(
+            'fake_policy', {'node.owner': '12345'}, {})
+        self.assertEqual(self.node, rpc_node)
+
+    @mock.patch.object(api, 'request', spec_set=["context", "version"])
+    @mock.patch.object(policy, 'authorize', spec=True)
+    @mock.patch.object(utils, 'get_rpc_node')
+    @mock.patch.object(utils, 'get_rpc_node_with_suffix')
+    def test_check_node_policy_and_retrieve_with_suffix(
+            self, mock_grnws, mock_grn, mock_authorize, mock_pr
+    ):
+        mock_pr.version.minor = 50
+        mock_pr.context.to_policy_values.return_value = {}
+        mock_grnws.return_value = self.node
+
+        rpc_node = utils.check_node_policy_and_retrieve(
+            'fake_policy', self.valid_node_uuid, True
+        )
+        mock_grn.assert_not_called()
+        mock_grnws.assert_called_once_with(self.valid_node_uuid)
+        mock_authorize.assert_called_once_with(
+            'fake_policy', {'node.owner': '12345'}, {})
+        self.assertEqual(self.node, rpc_node)
+
+    @mock.patch.object(api, 'request', spec_set=["context"])
+    @mock.patch.object(policy, 'authorize', spec=True)
+    @mock.patch.object(utils, 'get_rpc_node')
+    def test_check_node_policy_and_retrieve_no_node_policy_forbidden(
+            self, mock_grn, mock_authorize, mock_pr
+    ):
+        mock_pr.context.to_policy_values.return_value = {}
+        mock_authorize.side_effect = exception.HTTPForbidden(resource='fake')
+        mock_grn.side_effect = exception.NodeNotFound(
+            node=self.valid_node_uuid)
+
+        self.assertRaises(
+            exception.HTTPForbidden,
+            utils.check_node_policy_and_retrieve,
+            'fake-policy',
+            self.valid_node_uuid
+        )
+
+    @mock.patch.object(api, 'request', spec_set=["context"])
+    @mock.patch.object(policy, 'authorize', spec=True)
+    @mock.patch.object(utils, 'get_rpc_node')
+    def test_check_node_policy_and_retrieve_no_node(
+            self, mock_grn, mock_authorize, mock_pr
+    ):
+        mock_pr.context.to_policy_values.return_value = {}
+        mock_grn.side_effect = exception.NodeNotFound(
+            node=self.valid_node_uuid)
+
+        self.assertRaises(
+            exception.NodeNotFound,
+            utils.check_node_policy_and_retrieve,
+            'fake-policy',
+            self.valid_node_uuid
+        )
+
+    @mock.patch.object(api, 'request', spec_set=["context", "version"])
+    @mock.patch.object(policy, 'authorize', spec=True)
+    @mock.patch.object(utils, 'get_rpc_node')
+    def test_check_node_policy_and_retrieve_policy_forbidden(
+            self, mock_grn, mock_authorize, mock_pr
+    ):
+        mock_pr.version.minor = 50
+        mock_pr.context.to_policy_values.return_value = {}
+        mock_authorize.side_effect = exception.HTTPForbidden(resource='fake')
+        mock_grn.return_value = self.node
+
+        self.assertRaises(
+            exception.HTTPForbidden,
+            utils.check_node_policy_and_retrieve,
+            'fake-policy',
+            self.valid_node_uuid
+        )
+
+
+class TestCheckNodeListPolicy(base.TestCase):
+    @mock.patch.object(api, 'request', spec_set=["context", "version"])
+    @mock.patch.object(policy, 'authorize', spec=True)
+    def test_check_node_list_policy(
+            self, mock_authorize, mock_pr
+    ):
+        mock_pr.context.to_policy_values.return_value = {
+            'project_id': '12345'
+        }
+        mock_pr.version.minor = 50
+
+        owner = utils.check_node_list_policy()
+        self.assertIsNone(owner)
+
+    @mock.patch.object(api, 'request', spec_set=["context", "version"])
+    @mock.patch.object(policy, 'authorize', spec=True)
+    def test_check_node_list_policy_with_owner(
+            self, mock_authorize, mock_pr
+    ):
+        mock_pr.context.to_policy_values.return_value = {
+            'project_id': '12345'
+        }
+        mock_pr.version.minor = 50
+
+        owner = utils.check_node_list_policy('12345')
+        self.assertEqual(owner, '12345')
+
+    @mock.patch.object(api, 'request', spec_set=["context", "version"])
+    @mock.patch.object(policy, 'authorize', spec=True)
+    def test_check_node_list_policy_forbidden(
+            self, mock_authorize, mock_pr
+    ):
+        def mock_authorize_function(rule, target, creds):
+            raise exception.HTTPForbidden(resource='fake')
+        mock_authorize.side_effect = mock_authorize_function
+        mock_pr.context.to_policy_values.return_value = {
+            'project_id': '12345'
+        }
+        mock_pr.version.minor = 50
+
+        self.assertRaises(
+            exception.HTTPForbidden,
+            utils.check_node_list_policy,
+        )
+
+    @mock.patch.object(api, 'request', spec_set=["context", "version"])
+    @mock.patch.object(policy, 'authorize', spec=True)
+    def test_check_node_list_policy_forbidden_no_project(
+            self, mock_authorize, mock_pr
+    ):
+        def mock_authorize_function(rule, target, creds):
+            if rule == 'baremetal:node:list_all':
+                raise exception.HTTPForbidden(resource='fake')
+            return True
+        mock_authorize.side_effect = mock_authorize_function
+        mock_pr.context.to_policy_values.return_value = {}
+        mock_pr.version.minor = 50
+
+        self.assertRaises(
+            exception.HTTPForbidden,
+            utils.check_node_list_policy,
+        )
+
+    @mock.patch.object(api, 'request', spec_set=["context", "version"])
+    @mock.patch.object(policy, 'authorize', spec=True)
+    def test_check_node_list_policy_non_admin(
+            self, mock_authorize, mock_pr
+    ):
+        def mock_authorize_function(rule, target, creds):
+            if rule == 'baremetal:node:list_all':
+                raise exception.HTTPForbidden(resource='fake')
+            return True
+        mock_authorize.side_effect = mock_authorize_function
+        mock_pr.context.to_policy_values.return_value = {
+            'project_id': '12345'
+        }
+        mock_pr.version.minor = 50
+
+        owner = utils.check_node_list_policy()
+        self.assertEqual(owner, '12345')
+
+    @mock.patch.object(api, 'request', spec_set=["context", "version"])
+    @mock.patch.object(policy, 'authorize', spec=True)
+    def test_check_node_list_policy_non_admin_owner_proj_mismatch(
+            self, mock_authorize, mock_pr
+    ):
+        def mock_authorize_function(rule, target, creds):
+            if rule == 'baremetal:node:list_all':
+                raise exception.HTTPForbidden(resource='fake')
+            return True
+        mock_authorize.side_effect = mock_authorize_function
+        mock_pr.context.to_policy_values.return_value = {
+            'project_id': '12345'
+        }
+        mock_pr.version.minor = 50
+
+        self.assertRaises(
+            exception.HTTPForbidden,
+            utils.check_node_list_policy,
+            '54321'
+        )
+
+
+class TestCheckPortPolicyAndRetrieve(base.TestCase):
+    def setUp(self):
+        super(TestCheckPortPolicyAndRetrieve, self).setUp()
+        self.valid_port_uuid = uuidutils.generate_uuid()
+        self.node = test_api_utils.post_get_test_node()
+        self.node['owner'] = '12345'
+        self.port = objects.Port(self.context, node_id=42)
+
+    @mock.patch.object(api, 'request', spec_set=["context", "version"])
+    @mock.patch.object(policy, 'authorize', spec=True)
+    @mock.patch.object(objects.Port, 'get_by_uuid')
+    @mock.patch.object(objects.Node, 'get_by_id')
+    def test_check_port_policy_and_retrieve(
+            self, mock_ngbi, mock_pgbu, mock_authorize, mock_pr
+    ):
+        mock_pr.version.minor = 50
+        mock_pr.context.to_policy_values.return_value = {}
+        mock_pgbu.return_value = self.port
+        mock_ngbi.return_value = self.node
+
+        rpc_port, rpc_node = utils.check_port_policy_and_retrieve(
+            'fake_policy', self.valid_port_uuid
+        )
+        mock_pgbu.assert_called_once_with(mock_pr.context,
+                                          self.valid_port_uuid)
+        mock_ngbi.assert_called_once_with(mock_pr.context, 42)
+        mock_authorize.assert_called_once_with(
+            'fake_policy', {'node.owner': '12345'}, {})
+        self.assertEqual(self.port, rpc_port)
+        self.assertEqual(self.node, rpc_node)
+
+    @mock.patch.object(api, 'request', spec_set=["context"])
+    @mock.patch.object(policy, 'authorize', spec=True)
+    @mock.patch.object(objects.Port, 'get_by_uuid')
+    def test_check_port_policy_and_retrieve_no_port_policy_forbidden(
+            self, mock_pgbu, mock_authorize, mock_pr
+    ):
+        mock_pr.context.to_policy_values.return_value = {}
+        mock_authorize.side_effect = exception.HTTPForbidden(resource='fake')
+        mock_pgbu.side_effect = exception.PortNotFound(
+            port=self.valid_port_uuid)
+
+        self.assertRaises(
+            exception.HTTPForbidden,
+            utils.check_port_policy_and_retrieve,
+            'fake-policy',
+            self.valid_port_uuid
+        )
+
+    @mock.patch.object(api, 'request', spec_set=["context"])
+    @mock.patch.object(policy, 'authorize', spec=True)
+    @mock.patch.object(objects.Port, 'get_by_uuid')
+    def test_check_port_policy_and_retrieve_no_port(
+            self, mock_pgbu, mock_authorize, mock_pr
+    ):
+        mock_pr.context.to_policy_values.return_value = {}
+        mock_pgbu.side_effect = exception.PortNotFound(
+            port=self.valid_port_uuid)
+
+        self.assertRaises(
+            exception.PortNotFound,
+            utils.check_port_policy_and_retrieve,
+            'fake-policy',
+            self.valid_port_uuid
+        )
+
+    @mock.patch.object(api, 'request', spec_set=["context", "version"])
+    @mock.patch.object(policy, 'authorize', spec=True)
+    @mock.patch.object(objects.Port, 'get_by_uuid')
+    @mock.patch.object(objects.Node, 'get_by_id')
+    def test_check_port_policy_and_retrieve_policy_forbidden(
+            self, mock_ngbi, mock_pgbu, mock_authorize, mock_pr
+    ):
+        mock_pr.version.minor = 50
+        mock_pr.context.to_policy_values.return_value = {}
+        mock_authorize.side_effect = exception.HTTPForbidden(resource='fake')
+        mock_pgbu.return_value = self.port
+        mock_ngbi.return_value = self.node
+
+        self.assertRaises(
+            exception.HTTPForbidden,
+            utils.check_port_policy_and_retrieve,
+            'fake-policy',
+            self.valid_port_uuid
+        )
+
+
+class TestCheckPortListPolicy(base.TestCase):
+    @mock.patch.object(api, 'request', spec_set=["context", "version"])
+    @mock.patch.object(policy, 'authorize', spec=True)
+    def test_check_port_list_policy(
+            self, mock_authorize, mock_pr
+    ):
+        mock_pr.context.to_policy_values.return_value = {
+            'project_id': '12345'
+        }
+        mock_pr.version.minor = 50
+
+        owner = utils.check_port_list_policy()
+        self.assertIsNone(owner)
+
+    @mock.patch.object(api, 'request', spec_set=["context", "version"])
+    @mock.patch.object(policy, 'authorize', spec=True)
+    def test_check_port_list_policy_forbidden(
+            self, mock_authorize, mock_pr
+    ):
+        def mock_authorize_function(rule, target, creds):
+            raise exception.HTTPForbidden(resource='fake')
+        mock_authorize.side_effect = mock_authorize_function
+        mock_pr.context.to_policy_values.return_value = {
+            'project_id': '12345'
+        }
+        mock_pr.version.minor = 50
+
+        self.assertRaises(
+            exception.HTTPForbidden,
+            utils.check_port_list_policy,
+        )
+
+    @mock.patch.object(api, 'request', spec_set=["context", "version"])
+    @mock.patch.object(policy, 'authorize', spec=True)
+    def test_check_port_list_policy_forbidden_no_project(
+            self, mock_authorize, mock_pr
+    ):
+        def mock_authorize_function(rule, target, creds):
+            if rule == 'baremetal:port:list_all':
+                raise exception.HTTPForbidden(resource='fake')
+            return True
+        mock_authorize.side_effect = mock_authorize_function
+        mock_pr.context.to_policy_values.return_value = {}
+        mock_pr.version.minor = 50
+
+        self.assertRaises(
+            exception.HTTPForbidden,
+            utils.check_port_list_policy,
+        )
+
+    @mock.patch.object(api, 'request', spec_set=["context", "version"])
+    @mock.patch.object(policy, 'authorize', spec=True)
+    def test_check_port_list_policy_non_admin(
+            self, mock_authorize, mock_pr
+    ):
+        def mock_authorize_function(rule, target, creds):
+            if rule == 'baremetal:port:list_all':
+                raise exception.HTTPForbidden(resource='fake')
+            return True
+        mock_authorize.side_effect = mock_authorize_function
+        mock_pr.context.to_policy_values.return_value = {
+            'project_id': '12345'
+        }
+        mock_pr.version.minor = 50
+
+        owner = utils.check_port_list_policy()
+        self.assertEqual(owner, '12345')
