@@ -22,7 +22,6 @@ import mock
 from oslo_config import cfg
 from oslo_utils import fileutils
 from oslo_utils import uuidutils
-import six
 
 from ironic.common import exception
 from ironic.common.glance_service import image_service
@@ -122,7 +121,7 @@ class TestPXEUtils(db_base.DbTestCase):
         with open('ironic/tests/unit/drivers/pxe_config.template') as f:
             expected_template = f.read().rstrip()
 
-        self.assertEqual(six.text_type(expected_template), rendered_template)
+        self.assertEqual(str(expected_template), rendered_template)
 
     def test_default_ipxe_boot_script(self):
         rendered_template = utils.render_template(
@@ -132,7 +131,7 @@ class TestPXEUtils(db_base.DbTestCase):
         with open('ironic/tests/unit/drivers/boot.ipxe') as f:
             expected_template = f.read().rstrip()
 
-        self.assertEqual(six.text_type(expected_template), rendered_template)
+        self.assertEqual(str(expected_template), rendered_template)
 
     def test_default_ipxe_config(self):
         # NOTE(lucasagomes): iPXE is just an extension of the PXE driver,
@@ -154,7 +153,7 @@ class TestPXEUtils(db_base.DbTestCase):
         with open(templ_file) as f:
             expected_template = f.read().rstrip()
 
-        self.assertEqual(six.text_type(expected_template), rendered_template)
+        self.assertEqual(str(expected_template), rendered_template)
 
     def test_default_ipxe_timeout_config(self):
         # NOTE(lucasagomes): iPXE is just an extension of the PXE driver,
@@ -176,7 +175,7 @@ class TestPXEUtils(db_base.DbTestCase):
         with open(templ_file) as f:
             expected_template = f.read().rstrip()
 
-        self.assertEqual(six.text_type(expected_template), rendered_template)
+        self.assertEqual(str(expected_template), rendered_template)
 
     def test_default_ipxe_boot_from_volume_config(self):
         self.config(
@@ -195,7 +194,7 @@ class TestPXEUtils(db_base.DbTestCase):
         with open(templ_file) as f:
             expected_template = f.read().rstrip()
 
-        self.assertEqual(six.text_type(expected_template), rendered_template)
+        self.assertEqual(str(expected_template), rendered_template)
 
     def test_default_ipxe_boot_from_volume_config_no_extra_volumes(self):
         self.config(
@@ -217,7 +216,7 @@ class TestPXEUtils(db_base.DbTestCase):
                      'ipxe_config_boot_from_volume_no_extra_volumes.template'
         with open(templ_file) as f:
             expected_template = f.read().rstrip()
-        self.assertEqual(six.text_type(expected_template), rendered_template)
+        self.assertEqual(str(expected_template), rendered_template)
 
     def test_default_grub_config(self):
         pxe_opts = self.pxe_options
@@ -233,7 +232,7 @@ class TestPXEUtils(db_base.DbTestCase):
         with open(templ_file) as f:
             expected_template = f.read().rstrip()
 
-        self.assertEqual(six.text_type(expected_template), rendered_template)
+        self.assertEqual(str(expected_template), rendered_template)
 
     @mock.patch('ironic.common.utils.create_link_without_raise', autospec=True)
     @mock.patch('ironic_lib.utils.unlink_without_raise', autospec=True)
@@ -970,33 +969,6 @@ class TestPXEUtils(db_base.DbTestCase):
         relpath = pxe_utils.get_path_relative_to_tftp_root(test_file_path)
         self.assertEqual(relpath, 'pxelinux.cfg/test')
 
-    @mock.patch('ironic.common.utils.rmtree_without_raise', autospec=True)
-    @mock.patch('ironic_lib.utils.unlink_without_raise', autospec=True)
-    @mock.patch('ironic.common.dhcp_factory.DHCPFactory.provider',
-                autospec=True)
-    def test_clean_up_pxe_config_uefi_no_ipaddress(self, provider_mock,
-                                                   unlink_mock,
-                                                   rmtree_mock):
-        address = "aa:aa:aa:aa:aa:aa"
-        properties = {'capabilities': 'boot_mode:uefi'}
-        object_utils.create_test_port(self.context, node_id=self.node.id,
-                                      address=address)
-
-        provider_mock.get_ip_addresses.return_value = []
-
-        with task_manager.acquire(self.context, self.node.uuid) as task:
-            task.node.properties = properties
-            pxe_utils.clean_up_pxe_config(task)
-
-            unlink_calls = [
-                mock.call('/tftpboot/pxelinux.cfg/01-%s' %
-                          address.replace(':', '-')),
-                mock.call('/tftpboot/aa:aa:aa:aa:aa:aa.conf')
-            ]
-            unlink_mock.assert_has_calls(unlink_calls)
-            rmtree_mock.assert_called_once_with(
-                os.path.join(CONF.pxe.tftp_root, self.node.uuid))
-
 
 @mock.patch.object(ipxe.iPXEBoot, '__init__', lambda self: None)
 @mock.patch.object(pxe.PXEBoot, '__init__', lambda self: None)
@@ -1185,7 +1157,8 @@ class PXEInterfacesTestCase(db_base.DbTestCase):
     @mock.patch('ironic.common.utils.render_template', autospec=True)
     def _test_build_pxe_config_options_pxe(self, render_mock,
                                            whle_dsk_img=False,
-                                           debug=False, mode='deploy'):
+                                           debug=False, mode='deploy',
+                                           ramdisk_params=None):
         self.config(debug=debug)
         self.config(pxe_append_params='test_param', group='pxe')
         # NOTE: right '/' should be removed from url string
@@ -1237,6 +1210,9 @@ class PXEInterfacesTestCase(db_base.DbTestCase):
         expected_pxe_params = 'test_param'
         if debug:
             expected_pxe_params += ' ipa-debug=1'
+        if ramdisk_params:
+            expected_pxe_params += ' ' + ' '.join(
+                '%s=%s' % tpl for tpl in ramdisk_params.items())
 
         expected_options = {
             'deployment_ari_path': pxe_ramdisk,
@@ -1254,7 +1230,8 @@ class PXEInterfacesTestCase(db_base.DbTestCase):
 
         with task_manager.acquire(self.context, self.node.uuid,
                                   shared=True) as task:
-            options = pxe_utils.build_pxe_config_options(task, image_info)
+            options = pxe_utils.build_pxe_config_options(
+                task, image_info, ramdisk_params=ramdisk_params)
         self.assertEqual(expected_options, options)
 
     def test_build_pxe_config_options_pxe(self):
@@ -1284,6 +1261,10 @@ class PXEInterfacesTestCase(db_base.DbTestCase):
         self.node.save()
         self._test_build_pxe_config_options_pxe(whle_dsk_img=False)
 
+    def test_build_pxe_config_options_ramdisk_params(self):
+        self._test_build_pxe_config_options_pxe(whle_dsk_img=True,
+                                                ramdisk_params={'foo': 'bar'})
+
     def test_build_pxe_config_options_pxe_no_kernel_no_ramdisk(self):
         del self.node.driver_internal_info['is_whole_disk_image']
         self.node.save()
