@@ -224,6 +224,9 @@ def get_test_node(**kw):
         'owner': kw.get('owner', None),
         'allocation_id': kw.get('allocation_id'),
         'description': kw.get('description'),
+        'retired': kw.get('retired', False),
+        'retired_reason': kw.get('retired_reason', None),
+
     }
 
     for iface in drivers_base.ALL_INTERFACES:
@@ -595,6 +598,7 @@ def get_test_allocation(**kw):
         'updated_at': kw.get('updated_at'),
         'uuid': kw.get('uuid', uuidutils.generate_uuid()),
         'version': kw.get('version', allocation.Allocation.VERSION),
+        'owner': kw.get('owner', None),
     }
 
 
