@@ -15,7 +15,6 @@ import json
 from ironic_lib import utils as irlib_utils
 import mock
 from oslo_concurrency import processutils
-import six
 
 from ironic.common import exception
 from ironic.common import states
@@ -235,7 +234,7 @@ class TestAnsibleMethods(AnsibleDeployTestCaseBase):
                                 ansible_deploy._run_playbook,
                                 self.node, 'deploy', extra_vars,
                                 '/path/to/key')
-        self.assertIn('VIKINGS!', six.text_type(exc))
+        self.assertIn('VIKINGS!', str(exc))
         execute_mock.assert_called_once_with(
             'env', 'ANSIBLE_CONFIG=/path/to/config',
             'ansible-playbook', '/path/to/playbooks/deploy', '-i',
@@ -345,8 +344,10 @@ class TestAnsibleMethods(AnsibleDeployTestCaseBase):
             ansible_deploy._prepare_extra_vars(host_list, ansible_vars))
 
     def test__parse_root_device_hints(self):
-        hints = {"wwn": "fake wwn", "size": "12345", "rotational": True}
-        expected = {"wwn": "fake wwn", "size": 12345, "rotational": True}
+        hints = {"wwn": "fake wwn", "size": "12345", "rotational": True,
+                 "serial": "HELLO"}
+        expected = {"wwn": "fake wwn", "size": 12345, "rotational": True,
+                    "serial": "hello"}
         props = self.node.properties
         props['root_device'] = hints
         self.node.properties = props
@@ -355,6 +356,35 @@ class TestAnsibleMethods(AnsibleDeployTestCaseBase):
             self.assertEqual(
                 expected, ansible_deploy._parse_root_device_hints(task.node))
 
+    def test__parse_root_device_hints_iinfo(self):
+        hints = {"wwn": "fake wwn", "size": "12345", "rotational": True,
+                 "serial": "HELLO"}
+        expected = {"wwn": "fake wwn", "size": 12345, "rotational": True,
+                    "serial": "hello"}
+        iinfo = self.node.instance_info
+        iinfo['root_device'] = hints
+        self.node.instance_info = iinfo
+        self.node.save()
+        with task_manager.acquire(self.context, self.node.uuid) as task:
+            self.assertEqual(
+                expected, ansible_deploy._parse_root_device_hints(task.node))
+
+    def test__parse_root_device_hints_override(self):
+        hints = {"wwn": "fake wwn", "size": "12345", "rotational": True,
+                 "serial": "HELLO"}
+        expected = {"wwn": "fake wwn", "size": 12345, "rotational": True,
+                    "serial": "hello"}
+        props = self.node.properties
+        props['root_device'] = {'size': 'no idea'}
+        self.node.properties = props
+        iinfo = self.node.instance_info
+        iinfo['root_device'] = hints
+        self.node.instance_info = iinfo
+        self.node.save()
+        with task_manager.acquire(self.context, self.node.uuid) as task:
+            self.assertEqual(
+                expected, ansible_deploy._parse_root_device_hints(task.node))
+
     def test__parse_root_device_hints_fail_advanced(self):
         hints = {"wwn": "s!= fake wwn",
                  "size": ">= 12345",
@@ -372,25 +402,28 @@ class TestAnsibleMethods(AnsibleDeployTestCaseBase):
                 exception.InvalidParameterValue,
                 ansible_deploy._parse_root_device_hints, task.node)
             for key, value in expected.items():
-                self.assertIn(six.text_type(key), six.text_type(exc))
-                self.assertIn(six.text_type(value), six.text_type(exc))
+                self.assertIn(str(key), str(exc))
+                self.assertIn(str(value), str(exc))
+
+    def test__prepare_variables(self):
+        i_info = self.node.instance_info
+        i_info['image_mem_req'] = 3000
+        i_info['image_whatever'] = 'hello'
+        self.node.instance_info = i_info
+        self.node.save()
 
-    @mock.patch.object(ansible_deploy, '_calculate_memory_req', autospec=True,
-                       return_value=2000)
-    def test__prepare_variables(self, mem_req_mock):
         expected = {"image": {"url": "http://image",
                               "validate_certs": "yes",
                               "source": "fake-image",
-                              "mem_req": 2000,
+                              "mem_req": 3000,
                               "disk_format": "qcow2",
-                              "checksum": "md5:checksum"}}
+                              "checksum": "md5:checksum",
+                              "whatever": "hello"}}
         with task_manager.acquire(self.context, self.node.uuid) as task:
             self.assertEqual(expected,
                              ansible_deploy._prepare_variables(task))
 
-    @mock.patch.object(ansible_deploy, '_calculate_memory_req', autospec=True,
-                       return_value=2000)
-    def test__prepare_variables_root_device_hints(self, mem_req_mock):
+    def test__prepare_variables_root_device_hints(self):
         props = self.node.properties
         props['root_device'] = {"wwn": "fake-wwn"}
         self.node.properties = props
@@ -398,7 +431,6 @@ class TestAnsibleMethods(AnsibleDeployTestCaseBase):
         expected = {"image": {"url": "http://image",
                               "validate_certs": "yes",
                               "source": "fake-image",
-                              "mem_req": 2000,
                               "disk_format": "qcow2",
                               "checksum": "md5:checksum"},
                     "root_device_hints": {"wwn": "fake-wwn"}}
@@ -406,9 +438,7 @@ class TestAnsibleMethods(AnsibleDeployTestCaseBase):
             self.assertEqual(expected,
                              ansible_deploy._prepare_variables(task))
 
-    @mock.patch.object(ansible_deploy, '_calculate_memory_req', autospec=True,
-                       return_value=2000)
-    def test__prepare_variables_noglance(self, mem_req_mock):
+    def test__prepare_variables_insecure_activated(self):
         self.config(image_store_insecure=True, group='ansible')
         i_info = self.node.instance_info
         i_info['image_checksum'] = 'sha256:checksum'
@@ -417,16 +447,13 @@ class TestAnsibleMethods(AnsibleDeployTestCaseBase):
         expected = {"image": {"url": "http://image",
                               "validate_certs": "no",
                               "source": "fake-image",
-                              "mem_req": 2000,
                               "disk_format": "qcow2",
                               "checksum": "sha256:checksum"}}
         with task_manager.acquire(self.context, self.node.uuid) as task:
             self.assertEqual(expected,
                              ansible_deploy._prepare_variables(task))
 
-    @mock.patch.object(ansible_deploy, '_calculate_memory_req', autospec=True,
-                       return_value=2000)
-    def test__prepare_variables_configdrive_url(self, mem_req_mock):
+    def test__prepare_variables_configdrive_url(self):
         i_info = self.node.instance_info
         i_info['configdrive'] = 'http://configdrive_url'
         self.node.instance_info = i_info
@@ -434,7 +461,6 @@ class TestAnsibleMethods(AnsibleDeployTestCaseBase):
         expected = {"image": {"url": "http://image",
                               "validate_certs": "yes",
                               "source": "fake-image",
-                              "mem_req": 2000,
                               "disk_format": "qcow2",
                               "checksum": "md5:checksum"},
                     'configdrive': {'type': 'url',
@@ -443,9 +469,7 @@ class TestAnsibleMethods(AnsibleDeployTestCaseBase):
             self.assertEqual(expected,
                              ansible_deploy._prepare_variables(task))
 
-    @mock.patch.object(ansible_deploy, '_calculate_memory_req', autospec=True,
-                       return_value=2000)
-    def test__prepare_variables_configdrive_file(self, mem_req_mock):
+    def test__prepare_variables_configdrive_file(self):
         i_info = self.node.instance_info
         i_info['configdrive'] = 'fake-content'
         self.node.instance_info = i_info
@@ -456,7 +480,6 @@ class TestAnsibleMethods(AnsibleDeployTestCaseBase):
         expected = {"image": {"url": "http://image",
                               "validate_certs": "yes",
                               "source": "fake-image",
-                              "mem_req": 2000,
                               "disk_format": "qcow2",
                               "checksum": "md5:checksum"},
                     'configdrive': {'type': 'file',
@@ -491,9 +514,9 @@ class TestAnsibleMethods(AnsibleDeployTestCaseBase):
         exc = self.assertRaises(exception.NodeCleaningFailure,
                                 ansible_deploy._validate_clean_steps,
                                 steps, self.node.uuid)
-        self.assertIn("name foo, field ham.value", six.text_type(exc))
-        self.assertIn("name bar, field interface", six.text_type(exc))
-        self.assertIn("name undefined, field name", six.text_type(exc))
+        self.assertIn("name foo, field ham.value", str(exc))
+        self.assertIn("name bar, field interface", str(exc))
+        self.assertIn("name undefined, field name", str(exc))
 
     def test__validate_clean_steps_names_not_unique(self):
         steps = [{"name": "foo",
@@ -503,7 +526,7 @@ class TestAnsibleMethods(AnsibleDeployTestCaseBase):
         exc = self.assertRaises(exception.NodeCleaningFailure,
                                 ansible_deploy._validate_clean_steps,
                                 steps, self.node.uuid)
-        self.assertIn("unique names", six.text_type(exc))
+        self.assertIn("unique names", str(exc))
 
     @mock.patch.object(ansible_deploy.yaml, 'safe_load', autospec=True)
     def test__get_clean_steps(self, load_mock):
@@ -587,13 +610,18 @@ class TestAnsibleDeploy(AnsibleDeployTestCaseBase):
                 task.driver.boot, task)
             get_boot_mock.assert_called_once_with(task.node)
 
+    @mock.patch.object(ansible_deploy, '_calculate_memory_req', autospec=True,
+                       return_value=2000)
     @mock.patch.object(utils, 'node_power_action', autospec=True)
-    def test_deploy(self, power_mock):
+    def test_deploy(self, power_mock, mem_req_mock):
         with task_manager.acquire(
                 self.context, self.node['uuid'], shared=False) as task:
             driver_return = self.driver.deploy(task)
             self.assertEqual(driver_return, states.DEPLOYWAIT)
             power_mock.assert_called_once_with(task, states.REBOOT)
+            mem_req_mock.assert_called_once_with(task)
+            i_info = task.node.instance_info
+            self.assertEqual(i_info['image_mem_req'], 2000)
 
     @mock.patch.object(utils, 'node_power_action', autospec=True)
     def test_tear_down(self, power_mock):
