@@ -12,13 +12,12 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+from http import client as http_client
 import json
 
 import mock
 import requests
 import retrying
-import six
-from six.moves import http_client
 
 from ironic.common import exception
 from ironic import conf
@@ -31,7 +30,7 @@ CONF = conf.CONF
 
 class MockResponse(object):
     def __init__(self, text, status_code=http_client.OK):
-        assert isinstance(text, six.string_types)
+        assert isinstance(text, str)
         self.text = text
         self.status_code = status_code
 
@@ -192,17 +191,6 @@ class TestAgentClient(base.TestCase):
                     'api_version': CONF.agent.agent_api_version},
                 timeout=CONF.agent.command_timeout)
 
-    def test_get_commands_status_retries(self):
-        with mock.patch.object(self.client.session, 'get',
-                               autospec=True) as mock_get:
-            res = mock.MagicMock(spec_set=['json'])
-            res.json.return_value = {'commands': []}
-            mock_get.side_effect = [
-                requests.ConnectionError('boom'),
-                res]
-            self.assertEqual([], self.client.get_commands_status(self.node))
-            self.assertEqual(2, mock_get.call_count)
-
     def test_prepare_image(self):
         self.client._command = mock.MagicMock(spec_set=[])
         image_info = {'image_id': 'image'}
@@ -283,8 +271,7 @@ class TestAgentClient(base.TestCase):
             self.node, root_uuid, efi_system_part_uuid=efi_system_part_uuid,
             prep_boot_part_uuid=prep_boot_part_uuid)
         self.client._command.assert_called_once_with(
-            command_timeout_factor=2, node=self.node,
-            method='image.install_bootloader', params=params,
+            node=self.node, method='image.install_bootloader', params=params,
             wait=True)
 
     def test_install_bootloader(self):
