@@ -574,6 +574,16 @@ class IscsiDeployMethodsTestCase(db_base.DbTestCase):
             self.assertRaises(exception.InvalidParameterValue,
                               iscsi_deploy.validate, task)
 
+    @mock.patch('ironic.drivers.modules.deploy_utils.get_ironic_api_url')
+    def test_validate_invalid_root_device_hints_iinfo(self, mock_get_url):
+        mock_get_url.return_value = 'http://spam.ham/baremetal'
+        with task_manager.acquire(self.context, self.node.uuid,
+                                  shared=True) as task:
+            task.node.properties['root_device'] = {'size': 42}
+            task.node.instance_info['root_device'] = {'size': 'not-int'}
+            self.assertRaises(exception.InvalidParameterValue,
+                              iscsi_deploy.validate, task)
+
 
 class ISCSIDeployTestCase(db_base.DbTestCase):
 
@@ -1266,8 +1276,8 @@ class CleanUpFullFlowTestCase(db_base.DbTestCase):
                                   shared=True) as task:
             task.driver.deploy.clean_up(task)
             mock_get_instance_image_info.assert_called_with(task)
-            mock_get_deploy_image_info.assert_called_with(task.node,
-                                                          mode='deploy')
+            mock_get_deploy_image_info.assert_called_with(
+                task.node, mode='deploy', ipxe_enabled=False)
             set_dhcp_provider_mock.assert_called_once_with()
             clean_dhcp_mock.assert_called_once_with(task)
         for path in ([self.kernel_path, self.image_path, self.config_path]
