@@ -207,6 +207,19 @@ class PXEBootTestCase(db_base.DbTestCase):
                 self.assertRaises(exception.InvalidParameterValue,
                                   task.driver.boot.validate, task)
 
+    def test_validate_inspection(self):
+        with task_manager.acquire(self.context, self.node.uuid) as task:
+            task.driver.boot.validate_inspection(task)
+
+    def test_validate_inspection_no_inspection_ramdisk(self):
+        driver_info = self.node.driver_info
+        del driver_info['deploy_ramdisk']
+        self.node.driver_info = driver_info
+        self.node.save()
+        with task_manager.acquire(self.context, self.node.uuid) as task:
+            self.assertRaises(exception.UnsupportedDriverExtension,
+                              task.driver.boot.validate_inspection, task)
+
     @mock.patch.object(manager_utils, 'node_get_boot_mode', autospec=True)
     @mock.patch.object(manager_utils, 'node_set_boot_device', autospec=True)
     @mock.patch.object(dhcp_factory, 'DHCPFactory')
@@ -290,11 +303,11 @@ class PXEBootTestCase(db_base.DbTestCase):
                         ipxe_enabled=CONF.pxe.ipxe_enabled)
             if uefi:
                 mock_pxe_config.assert_called_once_with(
-                    task, {'foo': 'bar'}, CONF.pxe.uefi_pxe_config_template,
+                    task, {}, CONF.pxe.uefi_pxe_config_template,
                     ipxe_enabled=CONF.pxe.ipxe_enabled)
             else:
                 mock_pxe_config.assert_called_once_with(
-                    task, {'foo': 'bar'}, CONF.pxe.pxe_config_template,
+                    task, {}, CONF.pxe.pxe_config_template,
                     ipxe_enabled=CONF.pxe.ipxe_enabled)
 
     def test_prepare_ramdisk(self):
